***********************************************************************************
* Latin-TAXBEN - The Flexible Tax Simulator for Middle Income Countries
* Build 2012-1
*
* Program name: calc_dirtax.do
* Program purpose: This program uses the tax schedule and the taxbase to calculate income tax,
*			 social security contributions (and, perhaps, IETU taxes)
*
* Things to add
* Gross and Taxable Incomes to the Output Data
*
* Program created: 27 July 2010, by David Phillips
* Program updated: 09 November 2010, by David Phillips
* Program updated: 29 May 2012, by David Phillips (based on MEXTAX 2010 Build)
*
** Nombre del programa: calc_dirtax.do
** Objectivo del programa: Este programa usa el esquema de impuestos y la base imponible para calcular
**                          pagos por impuestos a la renta y contribuciones al sistema de seguridad social
** Programa creado: 27 Julio 2010, por David Phillips
** Programa actualizado: 09 November 2010, por David Phillips
** Programa actualizado: 29 May 2012, por David Phillips
***********************************************************************************

noi display "CALC DIRTAX"
noi display "CALCULAR IMPUESTO DIRECTO"


******************************************************
**************** SOCIAL SECURITY CALC ****************
** CALCULO DE LAS CONTRIBUCIONES A LA SEGURIDAD SOCIAL
******************************************************

* SET UP AMTS AND RATES VARS
** ESTABLECER AMTS Y TASAS

gen socsec_$D = 0
gen socrate_$D = 0

replace socsec_$D = 0 if formal==0

* CAPTURE NUMBER OF SOCIAL SECURITY SYSTEMS

local y = NUMSOCSECSYSTEMS

foreach A of numlist 1(1)`y' {

local z = NUMSOCSEC`A'

* CALCULATING FIXED QUOTAS FOR EACH SOCSEC BAND
** CALCULO DE CUOTAS FIJAS FOR EACH SOCSEC BAND

scalar SETSOCSEC`A'_1 = 0

foreach x of numlist 2(1)`z' {

	local zm = `x' - 1
	local zmm = `x' - 2

	scalar SETSOCSEC`A'_`x' = SETSOCSEC`A'_`zm' + SOCSEC`A'_`zm'*(LSOCSEC`A'_`zm' - LSOCSEC`A'_`zmm')

}

* CALCULATING THE AMOUNT OF SOCIAL SECURITY TO BE PAID

foreach x of numlist 1(1)`z' {

	local zm = `x' - 1

	replace socsec_$D = SETSOCSEC`A'_`x' + SOCSEC`A'_`x'*(socsec_inc - LSOCSEC`A'_`zm') if socsec_inc> LSOCSEC`A'_`zm' & socsec_inc<=LSOCSEC`A'_`x' & formal==`A'
	replace socrate_$D = SOCSEC`A'_`x' if socsec_inc> LSOCSEC`A'_`zm' & socsec_inc<=LSOCSEC`A'_`x' & formal==`A'

}


} /* END A LOOP */



****************************************************
**************** INCOME TAX CALC *******************
        ** CALCULO DEL IMPUESTO A LA RENTA
****************************************************

local z = NUMBANDS
local zz = NUMCREDS

* DEDUCT SOCIAL SECURITY CONTS IF PART OF TAX LAW
local zzz = 0
*local zzz = DEDUCTSOCSEC
replace taxable_inc = taxable_inc - socsec_$D if `zzz'==1

* CALCULATING FIXED QUOTAS FOR INC TAX
** CALCULO DE CUOTAS FIJAS PARA EL IMPUESTO A LA RENTA

	scalar SETAMT1 = 0

foreach x of numlist 2(1)`z' {
	scalar JUMP = 0
	local zm = `x' - 1
	local zmm = `x' - 2

	scalar SETAMT`x' = SETAMT`zm' + RATE`zm'*(BAND`zm' - BAND`zmm') 
	*+ JUMP`x'

}

* CALCULATING INCOME TAX AMOUNT
** CALCULO DEL MONTO TOTAL DE IMPUESTO SOBRE LA RENTA

gen inctax_$D = 0
gen taxrate_$D = 0

* First Add Up Standard Inc Tax
** Primero calcular impuesto sobre la renta total estandar

foreach x of numlist 1(1)`z' {

	local zm = `x' - 1

	replace inctax_$D = SETAMT`x' + RATE`x'*(taxable_inc - BAND`zm') if taxable_inc> BAND`zm' & taxable_inc<=BAND`x'
	replace taxrate_$D = RATE`x' if taxable_inc> BAND`zm' & taxable_inc<=BAND`x'

}


* Then Subsidy to Employment Income if NUMCREDS>0
** Luego sustraer subsidio al ingreso laboral  if NUMCREDS>0

if `zz'>0 {

        foreach x of numlist 1(1)`zz' {

            local zm = `x' - 1

                replace inctax_$D = inctax_$D - ACRED`x' if taxable_inc > LCRED`zm' & taxable_inc <= LCRED`x'

       }
}


* Then Apply the Cap to Average Tax Rate if One Applies
	/*
	local bb = MAXRATE
	replace taxrate_$D= `bb' if (inctax_$D/taxable_inc)>`bb' & (inctax_$D/taxable_inc)!=. 
	replace inctax_$D = `bb'*(taxable_inc) if (inctax_$D/taxable_inc)>`bb'
*/
****************************************************
***************** CALC NET INCOME ******************
             ** CALCULO DE INGRESO NETO
****************************************************

gen netinc_$D = gross_$D - socsec_$D - inctax_$D


* ARRANGE FILE FOR SAVING
** ORDENAR EL ARCHIVO PARA SER GUARDADO

keep $identlist numren socsec_$D socrate_$D gross_$D inctax_$D taxrate_$D netinc_$D

sort $identlist numren

local x = $indic_incidence

if `x' ==1 {

	save "$out//dir_$D", replace

}

if `x' ==2 {

	save "$out//dir_in_$sys2", replace

}

if `x' ==3 {

	save "$out//dir_in_$sys3", replace

}
