*******************************************************************************************************
* Latin-TAXBEN - The Flexible Tax Simulator for Middle Income Countries
* Build 2012-1
*
* Program name: calc_indirtax.do
* Program purpose: This program uses the tax schedule and expenditure data to calculate VAT and
*			 duties paid. This is at household level not individual (or family) level.
* Program created: 27 July 2010, by David Phillips
* Program updated: 24 February 2010, by David Phillips
* Program updated: 29 May 2012, by David Phillips (based on MEXTAX 2010 Build)
*
** Nombre del programa: calc_indirtax.do
** Objetivo del Programa: Este programa utiliza los datos de impuestos y gastos del hogar provistos al programa
** 				 para el clculo de IVA e impuestos pagados. Esto es a nivel del hogar, no a nivel
**				 individual (o familiar).
*******************************************************************************************************

*************************************************************************
**************MODULE indirtax: Calculate the IVA and IEPS****************
**				 MODULO indirtax: Clculo del IVA y del IEPS
*************************************************************************

****** PLEASE NOTE: $D IS THE TAX SYSTEM LOOPER ******

noi display "CALC INDIRTAX"

use "$in\\$indata_co", clear

* GET PRE-TAX EXPENDITURE - using (old) tax system prevalent  at the time when the micro-data was collected
** OBTENER GASTOS ANTES DE IMPUESTOS - usando el (viejo) sistema vigente al momento de recoleccion de micro-data

* THEN GET IEPS and VAT PAID FOR TAX REGIME UNDER STUDY (NEW REGIME)
** LUEGO OBTENER IEPS Y VAT PAGADOS EN EL REGIMEN IMPOSITIVO EN ESTUDIO (NUEVO REGIMEN)

local z = NUMGOODS

foreach x of numlist 1(1)`z' {

    * pre-IVA (after OLD IEPS) expenditure using OLD VAT
    ** gastos antes de IVA, despues de IEPS, usando las tasas de VAT viejas

	gen piva_`x' = exp`x'/(1+OVAT`x') if region == 0
	replace piva_`x' = exp`x'/(1+OBVAT`x')  if region ==1

}

	gen piva$D = 0

foreach x of numlist 1(1)`z' {

	* pre-tax (IVA and IEPS) expenditure, using OLD VAT and IEPS
    ** gasto antes de impuestos (IVA y IEPS), usando tasas viejas de VAT e IEPS

    replace piva_`x' = piva_`x'*(1/(1+ODUTIES`x'))

    * pre-tax total expenditure
    ** gasto total antes de impuestos

	replace piva$D = piva$D + piva_`x'

	* IEPS paid under new regime, using pre-tax expenditure
    ** IEPS pagado bajo en nuevo sistema, calculado usando gasto antes de impuestos

	gen ieps_`x' = piva_`x'*(DUTIES`x')

    * Expenditure pre-IVA and post-IEPS, under new regime
    ** Gasto antes de IVA, y despues de IEPS, bajo el nuevo regimen

	replace piva_`x' = piva_`x' + ieps_`x'

}


foreach x of numlist 1(1)`z' {

    * IVA paid under new regime, calculated using expenditure after IEPS,
    ** IVA pagado en el nuevo regimen impositivo, calculado usando gasto despues de IEPS

	gen iva_`x'  = piva_`x'*(VAT`x') if region== 0
	replace iva_`x' = piva_`x'*(BVAT`x') if region== 1

    * Expenditure after taxes under the new regimen, for each good category
    ** Gasto despues de impuestos en el nuevo regimen impositivo, para cada tipo de bien

	gen nexp`x'_$D = piva_`x'+iva_`x'

}

* DROP UNNEEDED VARIABLES
** BORRAR VARIABLES INNECESARIAS

drop piva_*

* GENERATE INDIRECT TAX TOTALS
** GENERAR IMPUESTOS INDIRECTOS TOTALES

gen ieps_tot$D = ieps_1
gen iva_tot$D = iva_1

foreach x of numlist 2(1)`z' {

	replace ieps_tot$D = ieps_tot$D+ieps_`x'
	replace iva_tot$D = iva_tot$D+iva_`x'

}

* ARRANGE FILE FOR SAVING
** ORDENAR EL ARCHIVO PARA SER GUARDADO

foreach x of numlist 1(1)`z' {

	rename ieps_`x' ieps_`x'_$D
	rename iva_`x' iva_`x'_$D
}

keep $identlist numren ieps_* iva_* nexp* piva$D

sort $identlist numren

save "$out//indir_$D", replace
