***********************************************************************************
* Latin-TAXBEN - The Flexible Tax Simulator for Middle Income Countries
* Build 2012-1
*
* Program name: do_distanalysis.do
* Program purpose: conducts distributional analysis (cash and percentage terms)
*                   calculates total revenue changes using sampling weights
*
* Things to add
* Gross and Taxable Income Totals to Decile and HHTYPE Tables
*
* Program created: 27 July 2010, by David Phillips
* Program updated: 11 November 2010, by David Phillips
* Program updated: 04 February 2011, by David Phillips
* Program updated: 28 June 2011, by David Phillips - major edit, new table outputs
* Program updated: 29 May 2012, by David Phillips (based on MEXTAX 2011 Build)
*
** Nombre del programa: do_distanalysis.do
** Objectivo del programa: genera analisis distributivo (en terminos absolutos y porcentuales)
**                          calcula total de impuestos pagados ponderado por factor de muestreo
**
** Programa creado: 27 Julio 2010, por David Phillips
** Programa actualizado: 11 Nov 2010, 04 Feb 2011, 28 Jun 2011, 29 May 2012 por David Phillips
***********************************************************************************

use "$out\\$outdata_hh", clear

* CALCULATING CHANGES IN TOTAL REVENUE FIGURES
** CALCULA CAMBIOS EN LA RECAUDACION TOTAL DE IMPUESTOS

qui {

gen num = 1

foreach Z in $sys2 $sys3 {

	foreach W in inctax socsec iva ieps tot {

		egen rev`W'`Z' = sum(hh_change_`W'`Z'*factor)

		tabstat rev`W'`Z', stats(mean) f(%20.0fc) by(num) save
		matrix a_`W'`Z' = (r(Stat1))
	}

}

}



capture program drop log_revenue
program define log_revenue

local q = $sys2
local r = $sys3

set logtype text
log using "$out//$logfilerevenue", replace

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~60s "Revenue raised from the tax reforms " /*
				*/ _newline "" /*
				*/ _newline "   Tax        {c |}" %~25s "Reform System `q'" %~25s "Reform System `r'"   /*
				*/ _newline "{hline 14}{c +}{hline 50}"  /*
				*/ _newline as text " ISR          {c |}" as result "    $" %16.0fc a_inctax`q'[1,1] "         $" %16.0fc a_inctax`r'[1,1]  /*
				*/ _newline as text " Soc. Sec.    {c |}" as result "    $" %16.0fc a_socsec`q'[1,1] "         $" %16.0fc a_socsec`r'[1,1]  /*
				*/ _newline as text " IVA          {c |}" as result "    $" %16.0fc a_iva`q'[1,1] "         $" %16.0fc a_iva`r'[1,1]  /*
				*/ _newline as text " IEPS         {c |}" as result "    $" %16.0fc a_ieps`q'[1,1] "         $" %16.0fc a_ieps`r'[1,1]  /*
				*/ _newline as text "{hline 14}{c +}{hline 50}"  /*
				*/ _newline as text " Total        {c |}" as result "    $" %16.0fc a_tot`q'[1,1] "         $" %16.0fc a_tot`r'[1,1]


log close

end

log_revenue

qui {

foreach Z in $sys2 $sys3 {

rename hh_change_inctax`Z' ch_it`Z'
rename hh_change_socsec`Z' ch_ss`Z'
rename hh_change_ieps`Z'   ch_ie`Z'
rename hh_change_iva`Z'	   ch_iv`Z'
rename hh_change_tot`Z'	   ch_to`Z'

}

rename eqsc_100100 es11
rename eqsc_8050 es85
rename eqsc_5030 es53

rename totexp texp
rename monexp mexp
rename totinc tinc
rename moninc minc

}

qui {

foreach X in es11 es85 es53 {

	foreach Y of varlist texp mexp tinc minc {

		gen `Y'_`X' = `Y'/`X'
		xtile dec`Y'_`X' = `Y'_`X' [fw=factor], nq(10)

	}
}
}

cap log close
set logtype text


* DO DISTRIBUTIONAL TABLES OF CHANGES IN TAXES PAID BY INCOME DECILE
** TABLAS CON CAMBIOS EN LOS IMPUESTOS PAGADOS POR DECIL DE INGRESO


capture program drop log_distanalysis
program define log_distanalysis


local x = $disttype

* FULL RANGE OF DISTRIBUTIONAL ANALYSES
** RANGO COMPLETO DE ANALISIS DISTRIBUTIVO

if `x' == 1 {

log using "$out//$logfiledecile", replace

foreach X in es11 es85 es53 {

	foreach M of varlist texp mexp tinc minc {
	
		egen num`M'_`X' = sum(factor), by(dec`M'_`X')
		
		foreach Y of varlist texp mexp tinc minc {
		
			qui {

				egen tot`Y'_dec`M'_`X' = sum(`Y'*factor), by(dec`M'_`X')
				gen ava`Y'_dec`M'_`X' = tot`Y'_dec`M'_`X'/num`M'_`X'

				foreach Z in $sys2 $sys3 {

					foreach W in ch_it ch_ss ch_iv ch_ie ch_to {

						egen tot`W'`Z'_`Y'`X'_d`M' = sum((-1)*`W'`Z'*factor), by(dec`M'_`X')
						gen cash`W'`Z'_`Y'`X'_d`M' = tot`W'`Z'_`Y'`X'_d`M'/num`M'_`X'
						gen prop`W'`Z'_`Y'`X'_d`M' = 100*(tot`W'`Z'_`Y'`X'_d`M'/tot`Y'_dec`M'_`X')


					}	/* end W */
				}		/* end Z */
			}		/* end qui */

		qui tabstat ava`Y'_dec`M'_`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
		matrix c0 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))


foreach Q in $sys2 $sys3 {
	qui {
			local Z = `Q'

			qui tabstat cashch_it`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_it`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_ss`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a2 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_ss`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b2 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_iv`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a3 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_iv`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b3 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_ie`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a4 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_ie`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b4 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_to`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a5 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_to`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b5 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
	}		/*end qui */

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "IMPACT OF REFORMS IN CASH TERMS USING DECILES OF `M' USING EQUIVALENCE SCALE `X' FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline "    Decile  {c |}" %~15s "`M'" %~10s "ISR" %~14s "Soc. Sec." %~13s "IVA" %~11s "IEPS" %~12s "TOTAL" /*
				*/ _newline "{hline 12}{c +}{hline 75}"  /*
				*/ _newline as text " Poorest    {c |}" as result "   $" %8.0fc c0[1,1] "   $" %8.0fc a1[1,1] "   $" %8.0fc a2[1,1] "   $" %8.0fc a3[1,1] "   $" %8.0fc a4[1,1] "   $" %8.0fc a5[1,1]  /*
				*/ _newline as text " Decile 2   {c |}" as result "   $" %8.0fc c0[1,2] "   $" %8.0fc a1[1,2] "   $" %8.0fc a2[1,2] "   $" %8.0fc a3[1,2] "   $" %8.0fc a4[1,2] "   $" %8.0fc a5[1,2]/*
				*/ _newline as text " Decile 3   {c |}" as result "   $" %8.0fc c0[1,3] "   $" %8.0fc a1[1,3] "   $" %8.0fc a2[1,3] "   $" %8.0fc a3[1,3] "   $" %8.0fc a4[1,3] "   $" %8.0fc a5[1,3]/*
				*/ _newline as text " Decile 4   {c |}" as result "   $" %8.0fc c0[1,4] "   $" %8.0fc a1[1,4] "   $" %8.0fc a2[1,4] "   $" %8.0fc a3[1,4] "   $" %8.0fc a4[1,4] "   $" %8.0fc a5[1,4]/*
				*/ _newline as text " Decile 5   {c |}" as result "   $" %8.0fc c0[1,5] "   $" %8.0fc a1[1,5] "   $" %8.0fc a2[1,5] "   $" %8.0fc a3[1,5] "   $" %8.0fc a4[1,5] "   $" %8.0fc a5[1,5]/*
				*/ _newline as text " Decile 6   {c |}" as result "   $" %8.0fc c0[1,6] "   $" %8.0fc a1[1,6] "   $" %8.0fc a2[1,6] "   $" %8.0fc a3[1,6] "   $" %8.0fc a4[1,6] "   $" %8.0fc a5[1,6]/*
				*/ _newline as text " Decile 7   {c |}" as result "   $" %8.0fc c0[1,7] "   $" %8.0fc a1[1,7] "   $" %8.0fc a2[1,7] "   $" %8.0fc a3[1,7] "   $" %8.0fc a4[1,7] "   $" %8.0fc a5[1,7]/*
				*/ _newline as text " Decile 8   {c |}" as result "   $" %8.0fc c0[1,8] "   $" %8.0fc a1[1,8] "   $" %8.0fc a2[1,8] "   $" %8.0fc a3[1,8] "   $" %8.0fc a4[1,8] "   $" %8.0fc a5[1,8]/*
				*/ _newline as text " Decile 9   {c |}" as result "   $" %8.0fc c0[1,9] "   $" %8.0fc a1[1,9] "   $" %8.0fc a2[1,9] "   $" %8.0fc a3[1,9] "   $" %8.0fc a4[1,9] "   $" %8.0fc a5[1,9]/*
				*/ _newline as text " Richest    {c |}" as result "   $" %8.0fc c0[1,10] "   $" %8.0fc a1[1,10] "   $" %8.0fc a2[1,10] "   $" %8.0fc a3[1,10] "   $" %8.0fc a4[1,10] "   $" %8.0fc a5[1,10]/*
				*/ _newline as text "{hline 12}{c +}{hline 75}"  /*
				*/ _newline as text " Average    {c |}" as result "   $" %8.0fc c0[1,11] "   $" %8.0fc a1[1,11] "   $" %8.0fc a2[1,11] "   $" %8.0fc a3[1,11] "   $" %8.0fc a4[1,11] "   $" %8.0fc a5[1,11]

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "IMPACT OF REFORMS AS A PROPORTION OF `Y' USING DECILES OF `M' AND EQUIVALENCE SCALE `X' FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline "    Decile  {c |}" %~15s "`M'" %~10s "ISR" %~10s "Soc. Sec." %~10s "IVA" %~8s "IEPS" %~14s "TOTAL" /*
				*/ _newline "{hline 12}{c +}{hline 65}"  /*
				*/ _newline as text " Poorest    {c |}" as result "   $" %8.0fc c0[1,1] "   " %6.2fc b1[1,1] "%   " %6.2fc b2[1,1] "%   " %6.2fc b3[1,1] "%   " %6.2fc b4[1,1] "%   " %6.2fc b5[1,1] "%   " /*
				*/ _newline as text " Decile 2   {c |}" as result "   $" %8.0fc c0[1,2] "   " %6.2fc b1[1,2] "%   " %6.2fc b2[1,2] "%   " %6.2fc b3[1,2] "%   " %6.2fc b4[1,2] "%   " %6.2fc b5[1,2] "%   "/*
				*/ _newline as text " Decile 3   {c |}" as result "   $" %8.0fc c0[1,3] "   " %6.2fc b1[1,3] "%   " %6.2fc b2[1,3] "%   " %6.2fc b3[1,3] "%   " %6.2fc b4[1,3] "%   " %6.2fc b5[1,3] "%   "/*
				*/ _newline as text " Decile 4   {c |}" as result "   $" %8.0fc c0[1,4] "   " %6.2fc b1[1,4] "%   " %6.2fc b2[1,4] "%   " %6.2fc b3[1,4] "%   " %6.2fc b4[1,4] "%   " %6.2fc b5[1,4] "%   "/*
				*/ _newline as text " Decile 5   {c |}" as result "   $" %8.0fc c0[1,5] "   " %6.2fc b1[1,5] "%   " %6.2fc b2[1,5] "%   " %6.2fc b3[1,5] "%   " %6.2fc b4[1,5] "%   " %6.2fc b5[1,5] "%   "/*
				*/ _newline as text " Decile 6   {c |}" as result "   $" %8.0fc c0[1,6] "   " %6.2fc b1[1,6] "%   " %6.2fc b2[1,6] "%   " %6.2fc b3[1,6] "%   " %6.2fc b4[1,6] "%   " %6.2fc b5[1,6] "%   "/*
				*/ _newline as text " Decile 7   {c |}" as result "   $" %8.0fc c0[1,7] "   " %6.2fc b1[1,7] "%   " %6.2fc b2[1,7] "%   " %6.2fc b3[1,7] "%   " %6.2fc b4[1,7] "%   " %6.2fc b5[1,7] "%   "/*
				*/ _newline as text " Decile 8   {c |}" as result "   $" %8.0fc c0[1,8] "   " %6.2fc b1[1,8] "%   " %6.2fc b2[1,8] "%   " %6.2fc b3[1,8] "%   " %6.2fc b4[1,8] "%   " %6.2fc b5[1,8] "%   "/*
				*/ _newline as text " Decile 9   {c |}" as result "   $" %8.0fc c0[1,9] "   " %6.2fc b1[1,9] "%   " %6.2fc b2[1,9] "%   " %6.2fc b3[1,9] "%   " %6.2fc b4[1,9] "%   " %6.2fc b5[1,9] "%   "/*
				*/ _newline as text " Richest    {c |}" as result "   $" %8.0fc c0[1,10] "   " %6.2fc b1[1,10] "%   " %6.2fc b2[1,10] "%   " %6.2fc b3[1,10] "%   " %6.2fc b4[1,10] "%   " %6.2fc b5[1,10] "%   "/*
				*/ _newline as text "{hline 12}{c +}{hline 65}"  /*
				*/ _newline as text " Average    {c |}" as result "   $" %8.0fc c0[1,11] "   " %6.2fc b1[1,11] "%   " %6.2fc b2[1,11] "%   " %6.2fc b3[1,11] "%   " %6.2fc b4[1,11] "%   " %6.2fc b5[1,11] "%   "/*
				*/ _newline as text " "/*
				*/ _newline as text " "/*
				*/ _newline as text "{hline 12}{c -}{hline 100}"
				
	} /* end Q */
	} /* end Y */
	} /* end M */
} 	  /* end X */

		drop totch* cashch* propch*

log close



drop tott* totm* num*


	foreach Y of varlist texp mexp tinc minc {

		egen tot`Y' = sum(`Y'*factor)

	}

	foreach W in ch_it ch_ss ch_iv ch_ie ch_to {

		foreach Z in $sys2 $sys3 {

			egen tot1`W'`Z' = sum(`W'`Z'*factor)

		}
	}

log using "$out//$logfiledecile1", replace

foreach X in es11 es85 es53 {

	foreach Y of varlist texp mexp tinc minc {

		qui {

				egen tot`Y'_`X' = sum(`Y'*factor), by(dec`Y'_`X')
				gen prop`Y'_`X' = 100*tot`Y'_`X'/tot`Y'

		foreach Z in $sys2 $sys3 {

			foreach W in ch_it ch_ss ch_iv ch_ie ch_to {

				egen tot`W'`Z'_`Y'`X' = sum(`W'`Z'*factor), by(dec`Y'_`X')
				gen prop`W'`Z'_`Y'`X' = 100*tot`W'`Z'_`Y'`X'/tot1`W'`Z'
				replace prop`W'`Z'_`Y'`X' = 0 if prop`W'`Z'_`Y'`X'==.


			}	/* end W*/
		}		/* end Z*/
		}		/* end qui*/


			qui tabstat prop`Y'_`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`Y'_`X') save
			matrix b0 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

foreach Q in $sys2 $sys3 {
	qui {
			local Z = `Q'

			qui tabstat propch_it`Z'_`Y'`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`Y'_`X') save
			matrix b1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat propch_ss`Z'_`Y'`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`Y'_`X') save
			matrix b2 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat propch_iv`Z'_`Y'`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`Y'_`X') save
			matrix b3 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat propch_ie`Z'_`Y'`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`Y'_`X') save
			matrix b4 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat propch_to`Z'_`Y'`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`Y'_`X') save
			matrix b5 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
	}		/* end qui */

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "PERCENTAGE OF ADDITIONAL REVENUE RAISED BY DECILES OF `Y' USING EQUIVALENCE SCALE `X' FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline "    Decile  {c |}" %~15s "`Y'" %~5s "ISR" %~14s "Soc. Sec." %~9s "IVA" %~8s "IEPS" %~11s "TOTAL" /*
				*/ _newline "{hline 12}{c +}{hline 80}"  /*
				*/ _newline as text " Poorest    {c |}" as result "   " %6.2fc b0[1,1] "%   " %6.2fc b1[1,1] "%   " %6.2fc b2[1,1] "%   " %6.2fc b3[1,1] "%   " %6.2fc b4[1,1] "%   " %6.2fc b5[1,1] "%   " /*
				*/ _newline as text " Decile 2   {c |}" as result "   " %6.2fc b0[1,2] "%   " %6.2fc b1[1,2] "%   " %6.2fc b2[1,2] "%   " %6.2fc b3[1,2] "%   " %6.2fc b4[1,2] "%   " %6.2fc b5[1,2] "%   "/*
				*/ _newline as text " Decile 3   {c |}" as result "   " %6.2fc b0[1,3] "%   " %6.2fc b1[1,3] "%   " %6.2fc b2[1,3] "%   " %6.2fc b3[1,3] "%   " %6.2fc b4[1,3] "%   " %6.2fc b5[1,3] "%   "/*
				*/ _newline as text " Decile 4   {c |}" as result "   " %6.2fc b0[1,4] "%   " %6.2fc b1[1,4] "%   " %6.2fc b2[1,4] "%   " %6.2fc b3[1,4] "%   " %6.2fc b4[1,4] "%   " %6.2fc b5[1,4] "%   "/*
				*/ _newline as text " Decile 5   {c |}" as result "   " %6.2fc b0[1,5] "%   " %6.2fc b1[1,5] "%   " %6.2fc b2[1,5] "%   " %6.2fc b3[1,5] "%   " %6.2fc b4[1,5] "%   " %6.2fc b5[1,5] "%   "/*
				*/ _newline as text " Decile 6   {c |}" as result "   " %6.2fc b0[1,6] "%   " %6.2fc b1[1,6] "%   " %6.2fc b2[1,6] "%   " %6.2fc b3[1,6] "%   " %6.2fc b4[1,6] "%   " %6.2fc b5[1,6] "%   "/*
				*/ _newline as text " Decile 7   {c |}" as result "   " %6.2fc b0[1,7] "%   " %6.2fc b1[1,7] "%   " %6.2fc b2[1,7] "%   " %6.2fc b3[1,7] "%   " %6.2fc b4[1,7] "%   " %6.2fc b5[1,7] "%   "/*
				*/ _newline as text " Decile 8   {c |}" as result "   " %6.2fc b0[1,8] "%   " %6.2fc b1[1,8] "%   " %6.2fc b2[1,8] "%   " %6.2fc b3[1,8] "%   " %6.2fc b4[1,8] "%   " %6.2fc b5[1,8] "%   "/*
				*/ _newline as text " Decile 9   {c |}" as result "   " %6.2fc b0[1,9] "%   " %6.2fc b1[1,9] "%   " %6.2fc b2[1,9] "%   " %6.2fc b3[1,9] "%   " %6.2fc b4[1,9] "%   " %6.2fc b5[1,9] "%   "/*
				*/ _newline as text " Richest    {c |}" as result "   " %6.2fc b0[1,10] "%   " %6.2fc b1[1,10] "%   " %6.2fc b2[1,10] "%   " %6.2fc b3[1,10] "%   " %6.2fc b4[1,10] "%   " %6.2fc b5[1,10] "%   "/*
				*/ _newline as text "{hline 12}{c +}{hline 80}"  /*
				*/ _newline as text " Average    {c |}" as result "   " %6.2fc b0[1,11] "%   " %6.2fc b1[1,11] "%   " %6.2fc b2[1,11] "%   " %6.2fc b3[1,11] "%   " %6.2fc b4[1,11] "%   " %6.2fc b5[1,11] "%   "/*
				*/ _newline as text " "/*
				*/ _newline as text " "/*
				*/ _newline as text "{hline 12}{c -}{hline 100}"
	} /* end Q*/


	} /* end Y */
} 	  /* end X */

log close


drop tott* totm* dec* prop* tot1*

}	/* end disttype */


* REDUCED RANGE OF DISTRIBUTIONAL ANALYSES
** RANGO REDUCIDO DE ANALISIS DISTRIBUTIVO


if `x' == 2 {

log using "$out//$logfiledecile", replace

foreach X in es85 {

	foreach M of varlist texp mexp tinc minc {
	
		egen num`M'_`X' = sum(factor), by(dec`M'_`X')

			foreach Y of varlist texp mexp tinc minc {

				qui {

					egen tot`Y'_dec`M'_`X' = sum(`Y'*factor), by(dec`M'_`X')
					gen ava`Y'_dec`M'_`X' = tot`Y'_dec`M'_`X'/num`M'_`X'

					foreach Z in $sys2 $sys3 {

						foreach W in ch_it ch_ss ch_iv ch_ie ch_to {

						egen tot`W'`Z'_`Y'`X'_d`M' = sum((-1)*`W'`Z'*factor), by(dec`M'_`X')
						gen cash`W'`Z'_`Y'`X'_d`M' = tot`W'`Z'_`Y'`X'_d`M'/num`M'_`X'
						gen prop`W'`Z'_`Y'`X'_d`M' = 100*(tot`W'`Z'_`Y'`X'_d`M'/tot`Y'_dec`M'_`X')


					}	/* end W */
				}		/* end Z */
			}		/* end qui */

		qui tabstat ava`Y'_dec`M'_`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
		matrix c0 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))


foreach Q in $sys2 $sys3 {
	qui {
			local Z = `Q'

			qui tabstat cashch_it`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_it`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_ss`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a2 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_ss`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b2 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_iv`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a3 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_iv`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b3 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_ie`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a4 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_ie`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b4 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_to`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a5 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_to`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b5 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
	}		/*end qui */

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "IMPACT OF REFORMS IN CASH TERMS USING DECILES OF `M' USING EQUIVALENCE SCALE `X' FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline "    Decile  {c |}" %~15s "`M'" %~10s "ISR" %~14s "Soc. Sec." %~13s "IVA" %~11s "IEPS" %~12s "TOTAL" /*
				*/ _newline "{hline 12}{c +}{hline 75}"  /*
				*/ _newline as text " Poorest    {c |}" as result "   $" %8.0fc c0[1,1] "   $" %8.0fc a1[1,1] "   $" %8.0fc a2[1,1] "   $" %8.0fc a3[1,1] "   $" %8.0fc a4[1,1] "   $" %8.0fc a5[1,1]  /*
				*/ _newline as text " Decile 2   {c |}" as result "   $" %8.0fc c0[1,2] "   $" %8.0fc a1[1,2] "   $" %8.0fc a2[1,2] "   $" %8.0fc a3[1,2] "   $" %8.0fc a4[1,2] "   $" %8.0fc a5[1,2]/*
				*/ _newline as text " Decile 3   {c |}" as result "   $" %8.0fc c0[1,3] "   $" %8.0fc a1[1,3] "   $" %8.0fc a2[1,3] "   $" %8.0fc a3[1,3] "   $" %8.0fc a4[1,3] "   $" %8.0fc a5[1,3]/*
				*/ _newline as text " Decile 4   {c |}" as result "   $" %8.0fc c0[1,4] "   $" %8.0fc a1[1,4] "   $" %8.0fc a2[1,4] "   $" %8.0fc a3[1,4] "   $" %8.0fc a4[1,4] "   $" %8.0fc a5[1,4]/*
				*/ _newline as text " Decile 5   {c |}" as result "   $" %8.0fc c0[1,5] "   $" %8.0fc a1[1,5] "   $" %8.0fc a2[1,5] "   $" %8.0fc a3[1,5] "   $" %8.0fc a4[1,5] "   $" %8.0fc a5[1,5]/*
				*/ _newline as text " Decile 6   {c |}" as result "   $" %8.0fc c0[1,6] "   $" %8.0fc a1[1,6] "   $" %8.0fc a2[1,6] "   $" %8.0fc a3[1,6] "   $" %8.0fc a4[1,6] "   $" %8.0fc a5[1,6]/*
				*/ _newline as text " Decile 7   {c |}" as result "   $" %8.0fc c0[1,7] "   $" %8.0fc a1[1,7] "   $" %8.0fc a2[1,7] "   $" %8.0fc a3[1,7] "   $" %8.0fc a4[1,7] "   $" %8.0fc a5[1,7]/*
				*/ _newline as text " Decile 8   {c |}" as result "   $" %8.0fc c0[1,8] "   $" %8.0fc a1[1,8] "   $" %8.0fc a2[1,8] "   $" %8.0fc a3[1,8] "   $" %8.0fc a4[1,8] "   $" %8.0fc a5[1,8]/*
				*/ _newline as text " Decile 9   {c |}" as result "   $" %8.0fc c0[1,9] "   $" %8.0fc a1[1,9] "   $" %8.0fc a2[1,9] "   $" %8.0fc a3[1,9] "   $" %8.0fc a4[1,9] "   $" %8.0fc a5[1,9]/*
				*/ _newline as text " Richest    {c |}" as result "   $" %8.0fc c0[1,10] "   $" %8.0fc a1[1,10] "   $" %8.0fc a2[1,10] "   $" %8.0fc a3[1,10] "   $" %8.0fc a4[1,10] "   $" %8.0fc a5[1,10]/*
				*/ _newline as text "{hline 12}{c +}{hline 75}"  /*
				*/ _newline as text " Average    {c |}" as result "   $" %8.0fc c0[1,11] "   $" %8.0fc a1[1,11] "   $" %8.0fc a2[1,11] "   $" %8.0fc a3[1,11] "   $" %8.0fc a4[1,11] "   $" %8.0fc a5[1,11]

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "IMPACT OF REFORMS AS A PROPORTION OF `Y' USING DECILES OF `M' AND EQUIVALENCE SCALE `X' FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline "    Decile  {c |}" %~15s "`M'" %~10s "ISR" %~10s "Soc. Sec." %~10s "IVA" %~8s "IEPS" %~14s "TOTAL" /*
				*/ _newline "{hline 12}{c +}{hline 65}"  /*
				*/ _newline as text " Poorest    {c |}" as result "   $" %8.0fc c0[1,1] "   " %6.2fc b1[1,1] "%   " %6.2fc b2[1,1] "%   " %6.2fc b3[1,1] "%   " %6.2fc b4[1,1] "%   " %6.2fc b5[1,1] "%   " /*
				*/ _newline as text " Decile 2   {c |}" as result "   $" %8.0fc c0[1,2] "   " %6.2fc b1[1,2] "%   " %6.2fc b2[1,2] "%   " %6.2fc b3[1,2] "%   " %6.2fc b4[1,2] "%   " %6.2fc b5[1,2] "%   "/*
				*/ _newline as text " Decile 3   {c |}" as result "   $" %8.0fc c0[1,3] "   " %6.2fc b1[1,3] "%   " %6.2fc b2[1,3] "%   " %6.2fc b3[1,3] "%   " %6.2fc b4[1,3] "%   " %6.2fc b5[1,3] "%   "/*
				*/ _newline as text " Decile 4   {c |}" as result "   $" %8.0fc c0[1,4] "   " %6.2fc b1[1,4] "%   " %6.2fc b2[1,4] "%   " %6.2fc b3[1,4] "%   " %6.2fc b4[1,4] "%   " %6.2fc b5[1,4] "%   "/*
				*/ _newline as text " Decile 5   {c |}" as result "   $" %8.0fc c0[1,5] "   " %6.2fc b1[1,5] "%   " %6.2fc b2[1,5] "%   " %6.2fc b3[1,5] "%   " %6.2fc b4[1,5] "%   " %6.2fc b5[1,5] "%   "/*
				*/ _newline as text " Decile 6   {c |}" as result "   $" %8.0fc c0[1,6] "   " %6.2fc b1[1,6] "%   " %6.2fc b2[1,6] "%   " %6.2fc b3[1,6] "%   " %6.2fc b4[1,6] "%   " %6.2fc b5[1,6] "%   "/*
				*/ _newline as text " Decile 7   {c |}" as result "   $" %8.0fc c0[1,7] "   " %6.2fc b1[1,7] "%   " %6.2fc b2[1,7] "%   " %6.2fc b3[1,7] "%   " %6.2fc b4[1,7] "%   " %6.2fc b5[1,7] "%   "/*
				*/ _newline as text " Decile 8   {c |}" as result "   $" %8.0fc c0[1,8] "   " %6.2fc b1[1,8] "%   " %6.2fc b2[1,8] "%   " %6.2fc b3[1,8] "%   " %6.2fc b4[1,8] "%   " %6.2fc b5[1,8] "%   "/*
				*/ _newline as text " Decile 9   {c |}" as result "   $" %8.0fc c0[1,9] "   " %6.2fc b1[1,9] "%   " %6.2fc b2[1,9] "%   " %6.2fc b3[1,9] "%   " %6.2fc b4[1,9] "%   " %6.2fc b5[1,9] "%   "/*
				*/ _newline as text " Richest    {c |}" as result "   $" %8.0fc c0[1,10] "   " %6.2fc b1[1,10] "%   " %6.2fc b2[1,10] "%   " %6.2fc b3[1,10] "%   " %6.2fc b4[1,10] "%   " %6.2fc b5[1,10] "%   "/*
				*/ _newline as text "{hline 12}{c +}{hline 65}"  /*
				*/ _newline as text " Average    {c |}" as result "   $" %8.0fc c0[1,11] "   " %6.2fc b1[1,11] "%   " %6.2fc b2[1,11] "%   " %6.2fc b3[1,11] "%   " %6.2fc b4[1,11] "%   " %6.2fc b5[1,11] "%   "/*
				*/ _newline as text " "/*
				*/ _newline as text " "/*
				*/ _newline as text "{hline 12}{c -}{hline 100}"
				
	} /* end Q */
	} /* end Y */
	} /* end M */
} 	  /* end X */

		drop totch* cashch* propch*

log close



drop tott* totm* num*


	foreach Y of varlist texp mexp tinc minc {

		egen tot`Y' = sum(`Y'*factor)

	}

	foreach W in ch_it ch_ss ch_iv ch_ie ch_to {

		foreach Z in $sys2 $sys3 {

			egen tot1`W'`Z' = sum(`W'`Z'*factor)

		}
	}

log using "$out//$logfiledecile1", replace

foreach X in es85  {

	foreach Y of varlist texp mexp tinc minc {

		qui {

				egen tot`Y'_`X' = sum(`Y'*factor), by(dec`Y'_`X')
				gen prop`Y'_`X' = 100*tot`Y'_`X'/tot`Y'

		foreach Z in $sys2 $sys3 {

			foreach W in ch_it ch_ss ch_iv ch_ie ch_to {

				egen tot`W'`Z'_`Y'`X' = sum(`W'`Z'*factor), by(dec`Y'_`X')
				gen prop`W'`Z'_`Y'`X' = 100*tot`W'`Z'_`Y'`X'/tot1`W'`Z'
				replace prop`W'`Z'_`Y'`X' = 0 if prop`W'`Z'_`Y'`X'==.


			}
		}

		local Z  = $sys2
		local ZZ = $sys3
		}


			qui tabstat prop`Y'_`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`Y'_`X') save
			matrix b0 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

foreach Q in $sys2 $sys3 {
	qui {
			local Z = `Q'

			qui tabstat propch_it`Z'_`Y'`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`Y'_`X') save
			matrix b1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat propch_ss`Z'_`Y'`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`Y'_`X') save
			matrix b2 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat propch_iv`Z'_`Y'`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`Y'_`X') save
			matrix b3 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat propch_ie`Z'_`Y'`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`Y'_`X') save
			matrix b4 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat propch_to`Z'_`Y'`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`Y'_`X') save
			matrix b5 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
	}

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "PERCENTAGE OF ADDITIONAL REVENUE RAISED BY DECILES OF `Y' USING EQUIVALENCE SCALE `X' FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline "    Decile  {c |}" %~15s "`Y'" %~5s "ISR" %~14s "Soc. Sec." %~9s "IVA" %~8s "IEPS" %~11s "TOTAL" /*
				*/ _newline "{hline 12}{c +}{hline 80}"  /*
				*/ _newline as text " Poorest    {c |}" as result "   " %6.2fc b0[1,1] "%   " %6.2fc b1[1,1] "%   " %6.2fc b2[1,1] "%   " %6.2fc b3[1,1] "%   " %6.2fc b4[1,1] "%   " %6.2fc b5[1,1] "%   " /*
				*/ _newline as text " Decile 2   {c |}" as result "   " %6.2fc b0[1,2] "%   " %6.2fc b1[1,2] "%   " %6.2fc b2[1,2] "%   " %6.2fc b3[1,2] "%   " %6.2fc b4[1,2] "%   " %6.2fc b5[1,2] "%   "/*
				*/ _newline as text " Decile 3   {c |}" as result "   " %6.2fc b0[1,3] "%   " %6.2fc b1[1,3] "%   " %6.2fc b2[1,3] "%   " %6.2fc b3[1,3] "%   " %6.2fc b4[1,3] "%   " %6.2fc b5[1,3] "%   "/*
				*/ _newline as text " Decile 4   {c |}" as result "   " %6.2fc b0[1,4] "%   " %6.2fc b1[1,4] "%   " %6.2fc b2[1,4] "%   " %6.2fc b3[1,4] "%   " %6.2fc b4[1,4] "%   " %6.2fc b5[1,4] "%   "/*
				*/ _newline as text " Decile 5   {c |}" as result "   " %6.2fc b0[1,5] "%   " %6.2fc b1[1,5] "%   " %6.2fc b2[1,5] "%   " %6.2fc b3[1,5] "%   " %6.2fc b4[1,5] "%   " %6.2fc b5[1,5] "%   "/*
				*/ _newline as text " Decile 6   {c |}" as result "   " %6.2fc b0[1,6] "%   " %6.2fc b1[1,6] "%   " %6.2fc b2[1,6] "%   " %6.2fc b3[1,6] "%   " %6.2fc b4[1,6] "%   " %6.2fc b5[1,6] "%   "/*
				*/ _newline as text " Decile 7   {c |}" as result "   " %6.2fc b0[1,7] "%   " %6.2fc b1[1,7] "%   " %6.2fc b2[1,7] "%   " %6.2fc b3[1,7] "%   " %6.2fc b4[1,7] "%   " %6.2fc b5[1,7] "%   "/*
				*/ _newline as text " Decile 8   {c |}" as result "   " %6.2fc b0[1,8] "%   " %6.2fc b1[1,8] "%   " %6.2fc b2[1,8] "%   " %6.2fc b3[1,8] "%   " %6.2fc b4[1,8] "%   " %6.2fc b5[1,8] "%   "/*
				*/ _newline as text " Decile 9   {c |}" as result "   " %6.2fc b0[1,9] "%   " %6.2fc b1[1,9] "%   " %6.2fc b2[1,9] "%   " %6.2fc b3[1,9] "%   " %6.2fc b4[1,9] "%   " %6.2fc b5[1,9] "%   "/*
				*/ _newline as text " Richest    {c |}" as result "   " %6.2fc b0[1,10] "%   " %6.2fc b1[1,10] "%   " %6.2fc b2[1,10] "%   " %6.2fc b3[1,10] "%   " %6.2fc b4[1,10] "%   " %6.2fc b5[1,10] "%   "/*
				*/ _newline as text "{hline 12}{c +}{hline 80}"  /*
				*/ _newline as text " Average    {c |}" as result "   " %6.2fc b0[1,11] "%   " %6.2fc b1[1,11] "%   " %6.2fc b2[1,11] "%   " %6.2fc b3[1,11] "%   " %6.2fc b4[1,11] "%   " %6.2fc b5[1,11] "%   "/*
				*/ _newline as text " "/*
				*/ _newline as text " "/*
				*/ _newline as text "{hline 12}{c -}{hline 100}"
	} /* end Q*/


	} /* end Y */
} 	  /* end X */

log close

drop tott* tot* dec* prop* tot1*

}	/* end disttype */



set logtype text
log using "$out//$logfilehhtype", replace

**** DO DISTRIBUTIONAL TABLES BY HOUSEHOLD TYPE ****

	foreach Y of varlist texp mexp tinc minc{

		qui {

				egen tot`Y' = sum(`Y'*factor), by(hhtype)
				egen num`Y' = sum(factor), by(hhtype)
				gen ava`Y' = tot`Y'/num`Y'


		foreach Z in $sys2 $sys3 {

			foreach W in ch_it ch_ss ch_iv ch_ie ch_to {

				egen tot`W'`Z'_`Y' = sum((-1)*`W'`Z'*factor), by(hhtype)
				gen cash`W'`Z'_`Y' = tot`W'`Z'_`Y'/num`Y'
				gen prop`W'`Z'_`Y' = 100*tot`W'`Z'_`Y'/tot`Y'


			}	/* end W */
		}		/* end Z */

		qui tabstat ava`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
		matrix c0 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
		}		/* end qui */

foreach Q in $sys2 $sys3 {
	qui {
			local Z = `Q'

			qui tabstat cashch_it`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix a1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_it`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix b1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_ss`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix a2 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_ss`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix b2 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_iv`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix a3 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_iv`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix b3 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_ie`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix a4 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_ie`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix b4 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_to`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix a5 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_to`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix b5 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
	}

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "IMPACT OF REFORMS IN CASH TERMS ACROSS HOUSEHOLDS (USING `Y' AS THE MEASURE OF LIVING STANDARDS) FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline 		"    HHType                 {c |}" %~15s "`Y'" %~10s "ISR" %~14s "Soc. Sec." %~13s "IVA" %~11s "IEPS" %~12s "TOTAL" /*
				*/ _newline "{hline 27}{c +}{hline 75}"  /*
				*/ _newline as text " Couple                    {c |}" as result "   $" %8.0fc c0[1,1] "   $" %8.0fc a1[1,1] "   $" %8.0fc a2[1,1] "   $" %8.0fc a3[1,1] "   $" %8.0fc a4[1,1] "   $" %8.0fc a5[1,1]  /*
				*/ _newline as text " Single                    {c |}" as result "   $" %8.0fc c0[1,2] "   $" %8.0fc a1[1,2] "   $" %8.0fc a2[1,2] "   $" %8.0fc a3[1,2] "   $" %8.0fc a4[1,2] "   $" %8.0fc a5[1,2]/*
				*/ _newline as text " Couple, children <18      {c |}" as result "   $" %8.0fc c0[1,3] "   $" %8.0fc a1[1,3] "   $" %8.0fc a2[1,3] "   $" %8.0fc a3[1,3] "   $" %8.0fc a4[1,3] "   $" %8.0fc a5[1,3]/*
				*/ _newline as text " Single, children <18      {c |}" as result "   $" %8.0fc c0[1,4] "   $" %8.0fc a1[1,4] "   $" %8.0fc a2[1,4] "   $" %8.0fc a3[1,4] "   $" %8.0fc a4[1,4] "   $" %8.0fc a5[1,4]/*
				*/ _newline as text " Pensioner, single         {c |}" as result "   $" %8.0fc c0[1,5] "   $" %8.0fc a1[1,5] "   $" %8.0fc a2[1,5] "   $" %8.0fc a3[1,5] "   $" %8.0fc a4[1,5] "   $" %8.0fc a5[1,5]/*
				*/ _newline as text " Pensioner, couple         {c |}" as result "   $" %8.0fc c0[1,6] "   $" %8.0fc a1[1,6] "   $" %8.0fc a2[1,6] "   $" %8.0fc a3[1,6] "   $" %8.0fc a4[1,6] "   $" %8.0fc a5[1,6]/*
				*/ _newline as text " Other family, no <18      {c |}" as result "   $" %8.0fc c0[1,7] "   $" %8.0fc a1[1,7] "   $" %8.0fc a2[1,7] "   $" %8.0fc a3[1,7] "   $" %8.0fc a4[1,7] "   $" %8.0fc a5[1,7]/*
				*/ _newline as text " Other family, with <18    {c |}" as result "   $" %8.0fc c0[1,8] "   $" %8.0fc a1[1,8] "   $" %8.0fc a2[1,8] "   $" %8.0fc a3[1,8] "   $" %8.0fc a4[1,8] "   $" %8.0fc a5[1,8]/*
				*/ _newline as text " Multi family, no <18      {c |}" as result "   $" %8.0fc c0[1,9] "   $" %8.0fc a1[1,9] "   $" %8.0fc a2[1,9] "   $" %8.0fc a3[1,9] "   $" %8.0fc a4[1,9] "   $" %8.0fc a5[1,9]/*
				*/ _newline as text " Multi family, with <18    {c |}" as result "   $" %8.0fc c0[1,10] "   $" %8.0fc a1[1,10] "   $" %8.0fc a2[1,10] "   $" %8.0fc a3[1,10] "   $" %8.0fc a4[1,10] "   $" %8.0fc a5[1,10]/*
				*/ _newline as text "{hline 27}{c +}{hline 75}"

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "IMPACT OF REFORMS AS A PROPORTION OF `Y' ACROSS HOUSEHOLDS (USING `Y' AS THE MEASURE OF LIVING STANDARDS) FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline 		"    HHType                 {c |}" %~15s "`Y'" %~10s "ISR" %~10s "Soc. Sec." %~10s "IVA" %~8s "IEPS" %~14s "TOTAL" /*
				*/ _newline "{hline 27}{c +}{hline 65}"  /*
				*/ _newline as text " Couple                    {c |}" as result "   $" %8.0fc c0[1,1] "   " %6.2fc b1[1,1] "%   " %6.2fc b2[1,1] "%   " %6.2fc b3[1,1] "%   " %6.2fc b4[1,1] "%   " %6.2fc b5[1,1] "%   " /*
				*/ _newline as text " Single                    {c |}" as result "   $" %8.0fc c0[1,2] "   " %6.2fc b1[1,2] "%   " %6.2fc b2[1,2] "%   " %6.2fc b3[1,2] "%   " %6.2fc b4[1,2] "%   " %6.2fc b5[1,2] "%   "/*
				*/ _newline as text " Couple, children <18      {c |}" as result "   $" %8.0fc c0[1,3] "   " %6.2fc b1[1,3] "%   " %6.2fc b2[1,3] "%   " %6.2fc b3[1,3] "%   " %6.2fc b4[1,3] "%   " %6.2fc b5[1,3] "%   "/*
				*/ _newline as text " Single, children <18      {c |}" as result "   $" %8.0fc c0[1,4] "   " %6.2fc b1[1,4] "%   " %6.2fc b2[1,4] "%   " %6.2fc b3[1,4] "%   " %6.2fc b4[1,4] "%   " %6.2fc b5[1,4] "%   "/*
				*/ _newline as text " Pensioner, single         {c |}" as result "   $" %8.0fc c0[1,5] "   " %6.2fc b1[1,5] "%   " %6.2fc b2[1,5] "%   " %6.2fc b3[1,5] "%   " %6.2fc b4[1,5] "%   " %6.2fc b5[1,5] "%   "/*
				*/ _newline as text " Pensioner, couple         {c |}" as result "   $" %8.0fc c0[1,6] "   " %6.2fc b1[1,6] "%   " %6.2fc b2[1,6] "%   " %6.2fc b3[1,6] "%   " %6.2fc b4[1,6] "%   " %6.2fc b5[1,6] "%   "/*
				*/ _newline as text " Other family, no <18      {c |}" as result "   $" %8.0fc c0[1,7] "   " %6.2fc b1[1,7] "%   " %6.2fc b2[1,7] "%   " %6.2fc b3[1,7] "%   " %6.2fc b4[1,7] "%   " %6.2fc b5[1,7] "%   "/*
				*/ _newline as text " Other family, with <18    {c |}" as result "   $" %8.0fc c0[1,8] "   " %6.2fc b1[1,8] "%   " %6.2fc b2[1,8] "%   " %6.2fc b3[1,8] "%   " %6.2fc b4[1,8] "%   " %6.2fc b5[1,8] "%   "/*
				*/ _newline as text " Multi family, no <18      {c |}" as result "   $" %8.0fc c0[1,9] "   " %6.2fc b1[1,9] "%   " %6.2fc b2[1,9] "%   " %6.2fc b3[1,9] "%   " %6.2fc b4[1,9] "%   " %6.2fc b5[1,9] "%   "/*
				*/ _newline as text " Multi family, with <18    {c |}" as result "   $" %8.0fc c0[1,10] "   " %6.2fc b1[1,10] "%   " %6.2fc b2[1,10] "%   " %6.2fc b3[1,10] "%   " %6.2fc b4[1,10] "%   " %6.2fc b5[1,10] "%   "/*
				*/ _newline as text "{hline 27}{c +}{hline 65}"  /*
				*/ _newline as text " "/*
				*/ _newline as text " "/*
				*/ _newline as text "{hline 12}{c -}{hline 100}"
	} /* end Q*/
	} /* end Y */


	log close

	end /* end program */

	log_distanalysis

	drop totch* cashch* propch*


