***********************************************************************************
* Latin-TAXBEN - The Flexible Tax Simulator for Middle Income Countries
* Build 2012-1
*
* Program name: do_household.do
* Program purpose: calculates the change in tax payments between reform systems
* Program created: 10 November 2010, by David Phillips
* Program updated: 29 May 2012, by David Phillips (based on MEXTAX 2010 Build)
*
** Nombre del programa: do_household.do
** Objectivo del programa: calcula la diferencia en pagos impositivo entre dos sistemas fiscales
** Programa creado: 10 Noviembre 2010, por  David Phillips
** Programa actualizado: 29 May 2012, por David Phillips
***********************************************************************************

*****************************************************************************
******* FIRSTLY CREATE THE ADULT LEVEL FILE (OBSERVATION LEVEL FILE) ********
                ** PRIMERO CREAR EL ARCHIVO A NIVEL DEL ADULTO/INDIVIDUAL
*****************************************************************************

* MERGING THE DATA
** COMBINANDO LAS BASES DE DATOS

use "$in\\$indata_ad.dta", clear

sort $identlist

merge $identlist using "$in\\$indata_hh.dta"

tab _merge

drop _merge


foreach Y in $sys1 $sys2 $sys3 {

global D = `Y'

	sort $identlist numren

	merge $identlist numren using "$out\\dir_$D.dta"

	tab _merge

	drop _merge

	sort $identlist numren

	merge $identlist numren using "$out\\indir_$D.dta", keep(ieps_tot$D iva_tot$D nexp* piva$D)

	tab _merge

	drop _merge

}

keep if totexp!=.

sort $identlist numren

* CALCULATING INDIV-LEVEL TAX AMOUNTS
** CALCULO DE IMPUESTOS PAGADOS A NIVEL INDIVIDUAL

foreach Y in $sys2 $sys3 {

global D = `Y'

	gen change_inctax$D = inctax_$D - inctax_$sys1
	gen change_socsec$D = socsec_$D - socsec_$sys1
	gen change_ieps$D = ieps_tot$D - ieps_tot$sys1
	gen change_iva$D = iva_tot$D - iva_tot$sys1

}

******************************************************************************
******* NOW CALCULATING HOUSEHOLD LEVEL AGGREGATES OF THE INDIV STUFF ********
  ** CALCULO DE LOS AGREGADOS LOS DATOS A NIVEL INDIVIDUAL A NIVEL DEL HOGAR
******************************************************************************

foreach Y in $sys2 $sys3 {

global D = `Y'

	egen hh_change_inctax$D = sum(change_inctax$D), by($identlist)
	egen hh_change_socsec$D = sum(change_socsec$D), by($identlist)
	egen hh_change_ieps$D = sum(change_ieps$D), by($identlist)
	egen hh_change_iva$D = sum(change_iva$D), by($identlist)
	gen  hh_change_tot$D = hh_change_inctax$D +hh_change_socsec$D +hh_change_ieps$D +hh_change_iva$D

}

foreach Y in $sys1 $sys2 $sys3 {

qui do "$param\params_`Y'.do"

global D = `Y'

	egen hhnet$D = sum(netinc_$D), by($identlist)

}

* CREATE NET INCOME FROM CALCULATED VALUES IF YOU HAVE TO
local Q = $netincometype

if `Q' == 1 {

	gen moninc = hhnet$sys1

	local R = NONMONNUM


	foreach Y of numlist 1(1)`R' {

        local Z = NONMONS`Y'
		replace moninc = moninc - inc`Z'

	}

	gen totinc = moninc + nmoninc

}


* ARRANGE FILE FOR SAVING
** ORDENAR EL ARCHIVO PARA SER GUARDADO

keep $identlist numren residentes menores mayores numfam eqsc* factor estrato ubica_geo tot* mon* nmon* age sex education empstat inc* taxrate* soc* ieps* iva* hh_change* hhtype hhnet*

sort $identlist numren

** SAVING INDIV-LEVEL FILE **

save "$out\\$outdata_ad", replace


* KEEPING ONLY FIRST ADULT
** GUARDAR SOLO EL PRIMER ADULTO DEL HOGAR

keep if numren == "01"
keep $identlist numren  eqsc* factor hh_change_* hhtype tot* mon* hhnet*
sort $identlist numren

save "$out\\$outdata_hh", replace
