***********************************************************************************
* Latin-TAXBEN - The Flexible Tax Simulator for Middle Income Countries
* Build 2012-1
*
* Program name: indirect_incidence.do
* Program purpose: This program allows one to carry out analyses assuming indirect taxes are partly incident on wages and profits
* 			 with 50% and 75% on prices as the default alternate scenarios, and with the fraction of that not on prices going
*			 on wages and profits being split according to the labor/capital income shares in national income.

* Program note: This do-file recalls the tax calculation do files after adjusting (formal) labour and income from business.
* 		    directly. It then includes an amended version of the distributional analysis do-files.
*		    The do file contains significant replications of the other do-files but amended to allow for the complexities of changes
*		    in gross wages, non-labour income, and pre-tax prices.

* Program created: 30 November 2010, by David Phillips
* Program updated: 30 November 2010, by David Phillips
* Program updated: 29 May 2012, by David Phillips (based on MEXTAX 2010 Build)
*
**
** Nombre del programa: indirect_incidence.do
** Objetivo del programa: Este programa permite generar analisis asumiendo que los impuestos indirectos recaen en parte sobre salarios y
**                        beneficios, en vez de 100% sobre los precios al consumidor. Los escenarios alternativos de referencia son de
**                        una incidencia sobre precios del 50% y 75%; con la fraccion que no incide sobre precios repartida entre
**                        salarios y beneficios de acuerdo a la participacion proporcional en el ingreso nacional del trabajo y capital respectivamente.
** Nota sobre el programa:  Este programa utiliza los programas para el calculo de impuestos luego de recalcular el ingreso (formal) proveniente del
**                          trabajo y proveniente de los negocios directamente. Luego incluye una version ajustada de los programa que realizan el
**                          analisis redistributivo. El programa contiene una cantidad significativa de comandos replicados de otros programas de MEXTAX
**                          pero ajustados para considerar las complejidades que resultan de los cambios en salarios brutos, ingreso no-laboral y precios
**                          antes de impuestos
** Programa creado: 30 Nov 2010, por David Phillips
** Programa actualizado: 30 Nov 2010, por David Phillips
** Programa actualizado: 29 May 2012, por David Phillips
***********************************************************************************


* Load data from the indirect tax calculations (performed in calc_indirtax.do) and input data from the files indata_ad and indata_hh
** Carga las bases de datos con los calculos de impuestos indirectos (realizados en calc_indirtax.do) y las bases de datos de entrada indata_ad y indata_hh

use "$out//indir_$sys1", clear

foreach Y in $sys2 $sys3 {

	sort folioviv foliohog numren
	merge folioviv foliohog numren using "$out//indir_`Y'"
	drop _merge

}

drop iva_*_* ieps_*_*

sort folioviv foliohog numren
merge folioviv foliohog numren using "$in\\$indata_ad.dta"
drop _merge

sort folioviv foliohog

merge folioviv foliohog using "$in\\$indata_hh.dta", keep(folioviv foliohog factor totexp)
gen region = 0
tab _merge
drop _merge

keep if totexp!=.


* THIS PART DOES THE STUFF ON THE IMPACT ON CONSUMER WELFARE THROUGH CONSUMER PRICES
* prop_prices = proportion of pass-through

** ESTA PARTE CALCULA EL IMPACTO EN EL BIENESTAR DEL CONSUMIDOR VIA PRECIOS DEL CONSUMIDOR
** prop_prices = proporcion de la transferencia de impuestos


foreach Y in $sys2 $sys3 {

	global D = `Y'

	gen change_ieps_tot$D = -(ieps_tot$D - ieps_tot$sys1)*$prop_prices
	gen change_iva_tot$D = -(iva_tot$D - iva_tot$sys1)*$prop_prices

*	gen change1_ieps_tot$D = -(ieps_tot$D - ieps_tot$sys1)
*	gen change1_iva_tot$D = -(iva_tot$D - iva_tot$sys1)


    *** *** *** *** *** *** *** *** *** ***
    *** WHAT'S THIS ABOVE and BELOW FOR??
    *** below change_indirtot$D is calculated again after nexp is recalculated using new rate of passthrough
    *** *** *** *** *** *** *** *** *** ***

	gen change_indirtot$D = 0

	foreach X of numlist 1(1)38 {

		replace change_indirtot$D = change_indirtot$D + nexp`X'_`Y' - nexp`X'_$sys1

	}

}

* NOW WE HAVE TO RECALCULATE THE PRE-TAX PRICES/EXPENDITURE UNDER THE REFORMS SYSTEMS AND THE LEVEL OF VAT / IEPS REVENUE BASED ON THIS
** RECALCULAR PRECIOS/GASTO ANTES DE IMPUESTOS Y EL NIVEL DE RECAUDACION DE IVA/IEPS BASADO EN ESTOS NUEVOS PRECIOS


* FROM CALC_INDIRTAX


qui do "$param\params_$sys1"

local z = NUMGOODS

qui {

foreach Y in $sys2 $sys3 {

	gen npiva`Y' = 0


	foreach X of numlist 1(1)`z' {

    * Adjusted NEW expenditure AFTER taxes under the new reform regimen, for each good category = nexp`X'_`Y' , adjusted by NEW PASS-THROUGH RATE
    * This assumes that quantities are unchanged, expenditure changes proportionally to the change in prices due to reforms,

		replace nexp`X'_`Y' = nexp`X'_`Y' - (1-$prop_prices)*(nexp`X'_`Y' - nexp`X'_$sys1)

		qui do "$param\params_`Y'.do"

    * Expenditure before VAT, after IEPS, under reform system

		gen piva_`X'_`Y' = nexp`X'_`Y'/(1+VAT`X') if region == 0
		replace piva_`X'_`Y' = nexp`X'_`Y'/(1+BVAT`X')  if region ==1

    * Expenditure before VAT, before IEPS, under reform system and accounting for less than full pass through

		replace piva_`X'_`Y' = piva_`X'_`Y'*(1/(1+DUTIES`X'))
		replace npiva`Y' = npiva`Y' + piva_`X'_`Y'

    * IEPS paid under reform regime, under incomplete pass through

		gen ieps_`X'_`Y' = DUTIES`X'*piva_`X'_`Y'

    * Expenditure post IEPS, pre IVA

		replace piva_`X'_`Y' =piva_`X'_`Y' +ieps_`X'_`Y'

	* IVA paid under new regime, under incomplete pass through

		gen iva_`X'_`Y' = piva_`X'_`Y'*VAT`X' if region==0
		replace iva_`X'_`Y' = piva_`X'_`Y'*BVAT`X' if region==1

	* Expenditure after indirect taxes, under incomplete pass through

		replace nexp`X'_`Y' = piva_`X'_`Y' + iva_`X'_`Y'

		drop piva_`X'_`Y'

	}


    * Calculate new totals for IEPS and IVA paid with incomplete pass-through

	gen nieps_tot`Y' = ieps_1_`Y'
	gen niva_tot`Y' = iva_1_`Y'

	foreach x of numlist 2(1)`z' {

		replace nieps_tot`Y' = nieps_tot`Y'+ieps_`x'_`Y'
		replace niva_tot`Y' = niva_tot`Y'+iva_`x'_`Y'

		drop ieps_`x'_`Y' iva_`x'_`Y'

	}

}

}

    * Calculate change in total taxes paid due to reform when incomplete pass-through

foreach Y in $sys2 $sys3 {

	global D = `Y'

	replace change_indirtot$D = 0

	foreach X of numlist 1(1)38 {

		replace change_indirtot$D = change_indirtot$D + nexp`X'_`Y' - nexp`X'_$sys1

	}

}

* NOW WE HAVE TO RECALCULATE DIRECT TAX PAYMENTS DUE TO CUTS IN INCOME

	egen wageinc = rsum(inc1 inc2 inc3 inc4 inc5 inc6 inc8)
	gen profinc = inc9

	egen totwageinc = sum(wageinc*factor)
	egen totprofinc = sum(profinc*factor)

foreach Y in $sys2 $sys3 {

	* pre-tax producers' revenue under base system
	egen totpiva`Y' = sum(piva`Y'*factor)

    * pre-tax producers' revenue under new reform system, accounting for the alternate pass through rate
	egen totnpiva`Y' = sum(npiva`Y'*factor)

	* change in pre-tax producers' revenue due to reform of which...
	gen producerchange`Y' = totpiva`Y' - totnpiva`Y'

        * ...a proportion is borne by workers in the form of lower wages
	gen wagechange`Y' = $prop_wages*producerchange`Y'

        * ...a proportion is borne by owners in the form of lower profits
	gen profchange`Y' = (1-$prop_wages)*producerchange`Y'


    * proportional change in wages and profits
 	gen pwage`Y' = wagechange`Y'/totwageinc
	gen pprof`Y' = profchange`Y'/totprofinc

}

    * calculate the change in (formal) employment income for each source, applying the same proportional change

foreach X in inc1 inc2 inc3 inc4 inc5 inc6 inc8 {
	foreach Y in $sys2 $sys3 {

		gen `X'_`Y' = `X'*(1-pwage`Y')
	}
}

    * calculate the change in (formal) NET(?) non-labor income

foreach X in inc9 {
	foreach Y in $sys2 $sys3 {

		gen `X'_`Y' = `X'*(1-(0.8*pprof`Y'))
	}
}


*** LA: WHAT IS THIS BELOW FOR?

/*
egen grossinc_ini = rsum( inc1 inc2 inc3 inc4 inc5 inc6 inc8 inc9)
egen grossinc_2010 = rsum( inc1_2010 inc2_2010 inc3_2010 inc4_2010 inc5_2010 inc6_2010 inc8_2010 inc9_2010)

egen hhgrossinc_ini = sum(grossinc_ini), by(folioviv foliohog)
replace hhgrossinc_ini= . if numren!="01"

egen hhgrossinc_2010 = sum(grossinc_2010), by(folioviv foliohog)
replace hhgrossinc_2010= . if numren!="01"
*/



    * these correspond to the informal income categories - so no adjustment needed

foreach X in inc7 inc10 inc11 inc12 inc13 inc14 inc15 inc16 inc17 inc18 inc19 inc20 {
	foreach Y in $sys2 $sys3 {

		gen `X'_`Y' = `X'
	}
}

    * generate new data on income after incomplete pass-through to calculate direct taxes paid

*** LA: does this overwrite previous data?

foreach Y in $sys2 $sys3 {

	preserve

		local z = NUMSOURCES

		keep folio* numren age sex education rel_head emp formal* inc*_`Y'

		sort folioviv foliohog numren

		foreach X of numlist 1(1)`z' {

			rename inc`X'_`Y' inc`X'

		}

		save "$in\\$indata_ad`Y'", replace

	restore

}

	keep folio* numren* change_ieps_tot* change_iva_tot* nieps_tot* niva_tot* ieps_tot* iva_tot*

	sort folioviv foliohog numren

	save "$out//indir_incidence", replace



* NOW RECALLING DIRECT TAX CALCULATIONS SEPARATELY GIVEN THE ADJUSTMENTS TO GROSS INCOME FOLLOWING LESS-THAN-FULL PASSTHROUGH OFI INDIRECT TAXES

*** sys2

global indic_incidence = 2
qui do "$param\params_$sys2"

foreach Y in $sys2 {

global D = `Y'

	qui do "$taxsim\set_taxbase.do"
	qui do "$taxsim\calc_dirtax.do"

}

*** sys3

global indic_incidence = 3
qui do "$param\params_$sys3"

foreach Y in $sys3 {

global D = `Y'

	qui do "$taxsim\set_taxbase.do"
	qui do "$taxsim\calc_dirtax.do"

}



* NOW DRAWING ON DO HOUSEHOLD.DO


* Merging the data

use "$in\\$indata_ad.dta", clear

keep folioviv foliohog numren age sex education empstat

sort folioviv foliohog

merge folioviv foliohog using "$in\\$indata_hh.dta"

drop _merge

sort folioviv foliohog numren

merge folioviv foliohog numren using "$out\\dir_$sys1"

drop _merge

sort folioviv foliohog numren

merge folioviv foliohog numren using "$out//indir_incidence"

drop _merge

foreach Y in $sys2 $sys3 {

global D = `Y'

	sort folioviv foliohog numren

	merge folioviv foliohog numren using "$out\\dir_in_$D.dta"

	drop _merge

}

* CALCULATING INDIV-LEVEL TAX AMOUNTS AND CHANGES IN PRICES / INCOMES

foreach Y in $sys2 $sys3 {

global D = `Y'

	gen change_inctax$D = inctax_$D - inctax_$sys1
	gen change_socsec$D = socsec_$D - socsec_$sys1
	gen change_ieps$D = nieps_tot$D - ieps_tot$sys1
	gen change_iva$D = niva_tot$D - iva_tot$sys1

	gen change_net$D = netinc_$D - netinc_$sys1
	gen change_pieps$D = change_ieps_tot$D
	gen change_piva$D = change_iva_tot$D

}

foreach Y in $sys2 $sys3 {

global D = `Y'

	egen hh_change_inctax$D = sum(change_inctax$D), by(folioviv foliohog)
	egen hh_change_socsec$D = sum(change_socsec$D), by(folioviv foliohog)
	egen hh_change_ieps$D = sum(change_ieps$D), by(folioviv foliohog)
	egen hh_change_iva$D = sum(change_iva$D), by(folioviv foliohog)
	gen  hh_change_tottax$D = hh_change_inctax$D +hh_change_socsec$D +hh_change_ieps$D +hh_change_iva$D
	egen hh_change_net$D = sum(change_net$D), by(folioviv foliohog)
	egen hh_change_pieps$D = sum(change_pieps$D), by(folioviv foliohog)
	egen hh_change_piva$D = sum(change_piva$D), by(folioviv foliohog)
	gen hh_change_ttinc$D = hh_change_net$D + hh_change_pieps$D + hh_change_piva$D


}

* ARRANGE FILE FOR SAVING

keep folioviv foliohog numren residentes menores mayores adult child numfam eqsc* factor estrato ubica_geo* tot* mon* nmon* age sex education empstat inc* taxrate* soc* ieps* iva* hh_change* net* hhtype tam_loc 

sort folioviv foliohog numren

* SAVING INDIV-LEVEL FILE

save "$out\\$outdata_ad_ind", replace


* KEEPING ONLY FIRST ADULT

keep if numren == "01"
keep folioviv foliohog  eqsc* factor hh_change_* hhtype tot* mon*
sort folioviv foliohog


* NOW DRAWING ON DO DISTANALYSIS.DO


* Firstly do the revenue figures

qui {

foreach Z in $sys2 $sys3 {

	foreach W in inctax socsec iva ieps tottax {

	egen rev`W'`Z' = sum(hh_change_`W'`Z'*factor)

	}
}

}
set logtype text
log using "$out//$logfilerevenue_ind", replace

sum rev*

log close

qui {

drop hh_change_inctax* hh_change_socsec* hh_change_ieps* hh_change_iva* hh_change_tot*

foreach Z in $sys2 $sys3 {

rename hh_change_net`Z'     ch_ne`Z'
rename hh_change_pieps`Z'   ch_ie`Z'
rename hh_change_piva`Z'    ch_iv`Z'
rename hh_change_ttinc`Z'   ch_to`Z'

}

rename eqsc_100100 es11
rename eqsc_8050 es85
rename eqsc_5030 es53

rename totexp texp
rename monexp mexp
rename totinc tinc
rename moninc minc

}
*
*******************************************************************************
* 					MODIFICO MEXTAX  - 6/6/2013 TANIA DIAZ BAZAN			  * 			 
*******************************************************************************

replace texp = texp + 150899


* CALCULATE THE EQUIVALISED INCOMES AND THE DECILES

qui {

foreach X in es11 es85 es53 {

	foreach Y of varlist texp mexp tinc minc {

		gen `Y'_`X' = `Y'/`X'
		xtile dec`Y'_`X' = `Y'_`X' [fw=factor], nq(10)

	}
}
}
set logtype text
log using "$out//$logfiledecile_ind", replace

* DO DISTRIBUTIONAL TABLES BY INCOME DECILE

local x = $disttype

if `x' == 1 {

foreach X in es11 es85 es53 {

	foreach M of varlist texp mexp tinc minc {
	
		egen num`M'_`X' = sum(factor), by(dec`M'_`X')

		foreach Y of varlist texp mexp tinc minc {
	
			qui {

				egen tot`Y'_dec`M'_`X' = sum(`Y'*factor), by(dec`M'_`X')				
				gen ava`Y'_dec`M'_`X' = tot`Y'_dec`M'_`X'/num`M'_`X'

				foreach Z in $sys2 $sys3 {

					foreach W in ch_ne ch_iv ch_ie ch_to {

						egen tot`W'`Z'_`Y'`X'_d`M' = sum(`W'`Z'*factor), by(dec`M'_`X')
						gen cash`W'`Z'_`Y'`X'_d`M' = tot`W'`Z'_`Y'`X'_d`M'/num`M'_`X'
						gen prop`W'`Z'_`Y'`X'_d`M' = 100*(tot`W'`Z'_`Y'`X'_d`M')/tot`Y'_dec`M'_`X'


					}	/* end W */
				}		/* end Z */
		}		/* end qui */

		qui tabstat ava`Y'_dec`M'_`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
		matrix c0 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))


foreach Q in $sys2 $sys3 {
	qui {
			local Z = `Q'

			qui tabstat cashch_ne`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_ne`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_iv`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a3 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_iv`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b3 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_ie`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a4 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_ie`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b4 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_to`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a5 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_to`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b5 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
	}		/*end qui */

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "IMPACT OF REFORMS IN CASH TERMS USING DECILES OF `Y' USING EQUIVALENCE SCALE `X' FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline "    Decile  {c |}" %~15s "`Y'" %~10s "Net Income" %~14s "IVA" %~12s "IEPS" %~13s "TOTAL" /*
				*/ _newline "{hline 12}{c +}{hline 65}"  /*
				*/ _newline as text " Poorest    {c |}" as result "   $" %8.0fc c0[1,1] "   $" %8.0fc a1[1,1] "   $" %8.0fc a3[1,1] "   $" %8.0fc a4[1,1] "   $" %8.0fc a5[1,1]  /*
				*/ _newline as text " Decile 2   {c |}" as result "   $" %8.0fc c0[1,2] "   $" %8.0fc a1[1,2] "   $" %8.0fc a3[1,2] "   $" %8.0fc a4[1,2] "   $" %8.0fc a5[1,2]/*
				*/ _newline as text " Decile 3   {c |}" as result "   $" %8.0fc c0[1,3] "   $" %8.0fc a1[1,3] "   $" %8.0fc a3[1,3] "   $" %8.0fc a4[1,3] "   $" %8.0fc a5[1,3]/*
				*/ _newline as text " Decile 4   {c |}" as result "   $" %8.0fc c0[1,4] "   $" %8.0fc a1[1,4] "   $" %8.0fc a3[1,4] "   $" %8.0fc a4[1,4] "   $" %8.0fc a5[1,4]/*
				*/ _newline as text " Decile 5   {c |}" as result "   $" %8.0fc c0[1,5] "   $" %8.0fc a1[1,5] "   $" %8.0fc a3[1,5] "   $" %8.0fc a4[1,5] "   $" %8.0fc a5[1,5]/*
				*/ _newline as text " Decile 6   {c |}" as result "   $" %8.0fc c0[1,6] "   $" %8.0fc a1[1,6] "   $" %8.0fc a3[1,6] "   $" %8.0fc a4[1,6] "   $" %8.0fc a5[1,6]/*
				*/ _newline as text " Decile 7   {c |}" as result "   $" %8.0fc c0[1,7] "   $" %8.0fc a1[1,7] "   $" %8.0fc a3[1,7] "   $" %8.0fc a4[1,7] "   $" %8.0fc a5[1,7]/*
				*/ _newline as text " Decile 8   {c |}" as result "   $" %8.0fc c0[1,8] "   $" %8.0fc a1[1,8] "   $" %8.0fc a3[1,8] "   $" %8.0fc a4[1,8] "   $" %8.0fc a5[1,8]/*
				*/ _newline as text " Decile 9   {c |}" as result "   $" %8.0fc c0[1,9] "   $" %8.0fc a1[1,9] "   $" %8.0fc a3[1,9] "   $" %8.0fc a4[1,9] "   $" %8.0fc a5[1,9]/*
				*/ _newline as text " Richest    {c |}" as result "   $" %8.0fc c0[1,10] "   $" %8.0fc a1[1,10] "   $" %8.0fc a3[1,10] "   $" %8.0fc a4[1,10] "   $" %8.0fc a5[1,10]/*
				*/ _newline as text "{hline 12}{c +}{hline 75}"  /*
				*/ _newline as text " Average    {c |}" as result "   $" %8.0fc c0[1,11] "   $" %8.0fc a1[1,11] "   $" %8.0fc a3[1,11] "   $" %8.0fc a4[1,11] "   $" %8.0fc a5[1,11]

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "IMPACT OF REFORMS AS A PROPORTION OF `Y' USING DECILES OF `M' USING EQUIVALENCE SCALE `X' FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline "    Decile  {c |}" %~15s "`Y'" %~10s "Net Income" %~10s "IVA" %~8s "IEPS" %~14s "TOTAL" /*
				*/ _newline "{hline 12}{c +}{hline 55}"  /*
				*/ _newline as text " Poorest    {c |}" as result "   $" %8.0fc c0[1,1] "   " %6.2fc b1[1,1] "%   " %6.2fc b3[1,1] "%   " %6.2fc b4[1,1] "%   " %6.2fc b5[1,1] "%   " /*
				*/ _newline as text " Decile 2   {c |}" as result "   $" %8.0fc c0[1,2] "   " %6.2fc b1[1,2] "%   " %6.2fc b3[1,2] "%   " %6.2fc b4[1,2] "%   " %6.2fc b5[1,2] "%   "/*
				*/ _newline as text " Decile 3   {c |}" as result "   $" %8.0fc c0[1,3] "   " %6.2fc b1[1,3] "%   " %6.2fc b3[1,3] "%   " %6.2fc b4[1,3] "%   " %6.2fc b5[1,3] "%   "/*
				*/ _newline as text " Decile 4   {c |}" as result "   $" %8.0fc c0[1,4] "   " %6.2fc b1[1,4] "%   " %6.2fc b3[1,4] "%   " %6.2fc b4[1,4] "%   " %6.2fc b5[1,4] "%   "/*
				*/ _newline as text " Decile 5   {c |}" as result "   $" %8.0fc c0[1,5] "   " %6.2fc b1[1,5] "%   " %6.2fc b3[1,5] "%   " %6.2fc b4[1,5] "%   " %6.2fc b5[1,5] "%   "/*
				*/ _newline as text " Decile 6   {c |}" as result "   $" %8.0fc c0[1,6] "   " %6.2fc b1[1,6] "%   " %6.2fc b3[1,6] "%   " %6.2fc b4[1,6] "%   " %6.2fc b5[1,6] "%   "/*
				*/ _newline as text " Decile 7   {c |}" as result "   $" %8.0fc c0[1,7] "   " %6.2fc b1[1,7] "%   " %6.2fc b3[1,7] "%   " %6.2fc b4[1,7] "%   " %6.2fc b5[1,7] "%   "/*
				*/ _newline as text " Decile 8   {c |}" as result "   $" %8.0fc c0[1,8] "   " %6.2fc b1[1,8] "%   " %6.2fc b3[1,8] "%   " %6.2fc b4[1,8] "%   " %6.2fc b5[1,8] "%   "/*
				*/ _newline as text " Decile 9   {c |}" as result "   $" %8.0fc c0[1,9] "   " %6.2fc b1[1,9] "%   " %6.2fc b3[1,9] "%   " %6.2fc b4[1,9] "%   " %6.2fc b5[1,9] "%   "/*
				*/ _newline as text " Richest    {c |}" as result "   $" %8.0fc c0[1,10] "   " %6.2fc b1[1,10] "%   " %6.2fc b3[1,10] "%   " %6.2fc b4[1,10] "%   " %6.2fc b5[1,10] "%   "/*
				*/ _newline as text "{hline 12}{c +}{hline 65}"  /*
				*/ _newline as text " Average    {c |}" as result "   $" %8.0fc c0[1,11] "   " %6.2fc b1[1,11] "%   " %6.2fc b3[1,11] "%   " %6.2fc b4[1,11] "%   " %6.2fc b5[1,11] "%   "/*
				*/ _newline as text " "/*
				*/ _newline as text " "/*
				*/ _newline as text "{hline 12}{c -}{hline 100}"
	} /* end Q*/
	} /* end Y */
	} /* END M */
} 	  /* end X */


		drop totch* cashch* propch*



} /* end x */


if `x' == 2 {

foreach X in eqsc85 {
	
	foreach M of varlist texp tinc {

		egen num`M'_`X' = sum(factor), by(dec`M'_`X')

		foreach Y of varlist texp tinc {
	
			qui {

				egen tot`Y'_dec`M'_`X' = sum(`Y'*factor), by(dec`M'_`X')				
				gen ava`Y'_dec`M'_`X' = tot`Y'_dec`M'_`X'/num`M'_`X'

				foreach Z in $sys2 $sys3 {

					foreach W in ch_ne ch_iv ch_ie ch_to {

						egen tot`W'`Z'_`Y'`X'_d`M' = sum(`W'`Z'*factor), by(dec`M'_`X')
						gen cash`W'`Z'_`Y'`X'_d`M' = tot`W'`Z'_`Y'`X'_d`M'/num`M'_`X'
						gen prop`W'`Z'_`Y'`X'_d`M' = 100*(tot`W'`Z'_`Y'`X'_d`M')/tot`Y'_dec`M'_`X'


					}	/* end W */
				}		/* end Z */
		}		/* end qui */

		qui tabstat ava`Y'_dec`M'_`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
		matrix c0 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))


foreach Q in $sys2 $sys3 {
	qui {
			local Z = `Q'

			qui tabstat cashch_ne`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_ne`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_iv`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a3 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_iv`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b3 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_ie`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a4 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_ie`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b4 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_to`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix a5 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_to`Z'_`Y'`X'_d`M' [fw=factor], stats(mean) f(%20.0fc) by(dec`M'_`X') save
			matrix b5 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
	}		/*end qui */

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "IMPACT OF REFORMS IN CASH TERMS USING DECILES OF `Y' USING EQUIVALENCE SCALE `X' FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline "    Decile  {c |}" %~15s "`Y'" %~10s "Net Income" %~14s "IVA" %~12s "IEPS" %~13s "TOTAL" /*
				*/ _newline "{hline 12}{c +}{hline 65}"  /*
				*/ _newline as text " Poorest    {c |}" as result "   $" %8.0fc c0[1,1] "   $" %8.0fc a1[1,1] "   $" %8.0fc a3[1,1] "   $" %8.0fc a4[1,1] "   $" %8.0fc a5[1,1]  /*
				*/ _newline as text " Decile 2   {c |}" as result "   $" %8.0fc c0[1,2] "   $" %8.0fc a1[1,2] "   $" %8.0fc a3[1,2] "   $" %8.0fc a4[1,2] "   $" %8.0fc a5[1,2]/*
				*/ _newline as text " Decile 3   {c |}" as result "   $" %8.0fc c0[1,3] "   $" %8.0fc a1[1,3] "   $" %8.0fc a3[1,3] "   $" %8.0fc a4[1,3] "   $" %8.0fc a5[1,3]/*
				*/ _newline as text " Decile 4   {c |}" as result "   $" %8.0fc c0[1,4] "   $" %8.0fc a1[1,4] "   $" %8.0fc a3[1,4] "   $" %8.0fc a4[1,4] "   $" %8.0fc a5[1,4]/*
				*/ _newline as text " Decile 5   {c |}" as result "   $" %8.0fc c0[1,5] "   $" %8.0fc a1[1,5] "   $" %8.0fc a3[1,5] "   $" %8.0fc a4[1,5] "   $" %8.0fc a5[1,5]/*
				*/ _newline as text " Decile 6   {c |}" as result "   $" %8.0fc c0[1,6] "   $" %8.0fc a1[1,6] "   $" %8.0fc a3[1,6] "   $" %8.0fc a4[1,6] "   $" %8.0fc a5[1,6]/*
				*/ _newline as text " Decile 7   {c |}" as result "   $" %8.0fc c0[1,7] "   $" %8.0fc a1[1,7] "   $" %8.0fc a3[1,7] "   $" %8.0fc a4[1,7] "   $" %8.0fc a5[1,7]/*
				*/ _newline as text " Decile 8   {c |}" as result "   $" %8.0fc c0[1,8] "   $" %8.0fc a1[1,8] "   $" %8.0fc a3[1,8] "   $" %8.0fc a4[1,8] "   $" %8.0fc a5[1,8]/*
				*/ _newline as text " Decile 9   {c |}" as result "   $" %8.0fc c0[1,9] "   $" %8.0fc a1[1,9] "   $" %8.0fc a3[1,9] "   $" %8.0fc a4[1,9] "   $" %8.0fc a5[1,9]/*
				*/ _newline as text " Richest    {c |}" as result "   $" %8.0fc c0[1,10] "   $" %8.0fc a1[1,10] "   $" %8.0fc a3[1,10] "   $" %8.0fc a4[1,10] "   $" %8.0fc a5[1,10]/*
				*/ _newline as text "{hline 12}{c +}{hline 75}"  /*
				*/ _newline as text " Average    {c |}" as result "   $" %8.0fc c0[1,11] "   $" %8.0fc a1[1,11] "   $" %8.0fc a3[1,11] "   $" %8.0fc a4[1,11] "   $" %8.0fc a5[1,11]

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "IMPACT OF REFORMS AS A PROPORTION OF `Y' USING DECILES OF `M' USING EQUIVALENCE SCALE `X' FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline "    Decile  {c |}" %~15s "`Y'" %~10s "Net Income" %~10s "IVA" %~8s "IEPS" %~14s "TOTAL" /*
				*/ _newline "{hline 12}{c +}{hline 55}"  /*
				*/ _newline as text " Poorest    {c |}" as result "   $" %8.0fc c0[1,1] "   " %6.2fc b1[1,1] "%   " %6.2fc b3[1,1] "%   " %6.2fc b4[1,1] "%   " %6.2fc b5[1,1] "%   " /*
				*/ _newline as text " Decile 2   {c |}" as result "   $" %8.0fc c0[1,2] "   " %6.2fc b1[1,2] "%   " %6.2fc b3[1,2] "%   " %6.2fc b4[1,2] "%   " %6.2fc b5[1,2] "%   "/*
				*/ _newline as text " Decile 3   {c |}" as result "   $" %8.0fc c0[1,3] "   " %6.2fc b1[1,3] "%   " %6.2fc b3[1,3] "%   " %6.2fc b4[1,3] "%   " %6.2fc b5[1,3] "%   "/*
				*/ _newline as text " Decile 4   {c |}" as result "   $" %8.0fc c0[1,4] "   " %6.2fc b1[1,4] "%   " %6.2fc b3[1,4] "%   " %6.2fc b4[1,4] "%   " %6.2fc b5[1,4] "%   "/*
				*/ _newline as text " Decile 5   {c |}" as result "   $" %8.0fc c0[1,5] "   " %6.2fc b1[1,5] "%   " %6.2fc b3[1,5] "%   " %6.2fc b4[1,5] "%   " %6.2fc b5[1,5] "%   "/*
				*/ _newline as text " Decile 6   {c |}" as result "   $" %8.0fc c0[1,6] "   " %6.2fc b1[1,6] "%   " %6.2fc b3[1,6] "%   " %6.2fc b4[1,6] "%   " %6.2fc b5[1,6] "%   "/*
				*/ _newline as text " Decile 7   {c |}" as result "   $" %8.0fc c0[1,7] "   " %6.2fc b1[1,7] "%   " %6.2fc b3[1,7] "%   " %6.2fc b4[1,7] "%   " %6.2fc b5[1,7] "%   "/*
				*/ _newline as text " Decile 8   {c |}" as result "   $" %8.0fc c0[1,8] "   " %6.2fc b1[1,8] "%   " %6.2fc b3[1,8] "%   " %6.2fc b4[1,8] "%   " %6.2fc b5[1,8] "%   "/*
				*/ _newline as text " Decile 9   {c |}" as result "   $" %8.0fc c0[1,9] "   " %6.2fc b1[1,9] "%   " %6.2fc b3[1,9] "%   " %6.2fc b4[1,9] "%   " %6.2fc b5[1,9] "%   "/*
				*/ _newline as text " Richest    {c |}" as result "   $" %8.0fc c0[1,10] "   " %6.2fc b1[1,10] "%   " %6.2fc b3[1,10] "%   " %6.2fc b4[1,10] "%   " %6.2fc b5[1,10] "%   "/*
				*/ _newline as text "{hline 12}{c +}{hline 65}"  /*
				*/ _newline as text " Average    {c |}" as result "   $" %8.0fc c0[1,11] "   " %6.2fc b1[1,11] "%   " %6.2fc b3[1,11] "%   " %6.2fc b4[1,11] "%   " %6.2fc b5[1,11] "%   "/*
				*/ _newline as text " "/*
				*/ _newline as text " "/*
				*/ _newline as text "{hline 12}{c -}{hline 100}"
	} /* end Q*/
	} /* end Y */
	} /* END M */
} 	  /* end X */


drop totch* cashch* propch*

}

drop tott* totm* num* dec*

log close
set logtype text
log using "$out//$logfilehhtype_ind", replace

**** DO DISTRIBUTIONAL TABLES BY HOUSEHOLD TYPE ****

	foreach Y of varlist texp mexp tinc minc {

		qui {

				egen tot`Y' = sum(`Y'*factor), by(hhtype)
				egen num`Y' = sum(factor), by(hhtype)
				gen ava`Y' = tot`Y'/num`Y'


		foreach Z in $sys2 $sys3 {

			foreach W in ch_ne ch_iv ch_ie ch_to {

				egen tot`W'`Z'_`Y' = sum(`W'`Z'*factor), by(hhtype)
				gen cash`W'`Z'_`Y' = tot`W'`Z'_`Y'/num`Y'
				gen prop`W'`Z'_`Y' = tot`W'`Z'_`Y'/tot`Y'


				}	/* end W */
		}		/* end Z */

		qui tabstat ava`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
		matrix c0 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
		}		/* end qui */

foreach Q in $sys2 $sys3 {
	qui {
			local Z = `Q'

			qui tabstat cashch_ne`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix a1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_ne`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix b1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_iv`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix a3 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_iv`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix b3 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_ie`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix a4 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_ie`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix b4 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashch_to`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix a5 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propch_to`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix b5 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
	}

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "IMPACT OF REFORMS IN CASH TERMS ACROSS HOUSEHOLDS USING `Y' AS THE MEASURE OF LIVING STANDARDS FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline 		"    Decile                 {c |}" %~15s "`Y'" %~10s "Net income" %~15s "IVA" %~11s "IEPS" %~12s "TOTAL" /*
				*/ _newline "{hline 27}{c +}{hline 75}"  /*
				*/ _newline as text " Couple                    {c |}" as result "   $" %8.0fc c0[1,1] "   $" %8.0fc a1[1,1] "   $" %8.0fc a3[1,1] "   $" %8.0fc a4[1,1] "   $" %8.0fc a5[1,1]  /*
				*/ _newline as text " Single                    {c |}" as result "   $" %8.0fc c0[1,2] "   $" %8.0fc a1[1,2] "   $" %8.0fc a3[1,2] "   $" %8.0fc a4[1,2] "   $" %8.0fc a5[1,2]/*
				*/ _newline as text " Couple, children <18      {c |}" as result "   $" %8.0fc c0[1,3] "   $" %8.0fc a1[1,3] "   $" %8.0fc a3[1,3] "   $" %8.0fc a4[1,3] "   $" %8.0fc a5[1,3]/*
				*/ _newline as text " Single, children <18      {c |}" as result "   $" %8.0fc c0[1,4] "   $" %8.0fc a1[1,4] "   $" %8.0fc a3[1,4] "   $" %8.0fc a4[1,4] "   $" %8.0fc a5[1,4]/*
				*/ _newline as text " Pensioner, single         {c |}" as result "   $" %8.0fc c0[1,5] "   $" %8.0fc a1[1,5] "   $" %8.0fc a3[1,5] "   $" %8.0fc a4[1,5] "   $" %8.0fc a5[1,5]/*
				*/ _newline as text " Pensioner, couple         {c |}" as result "   $" %8.0fc c0[1,6] "   $" %8.0fc a1[1,6] "   $" %8.0fc a3[1,6] "   $" %8.0fc a4[1,6] "   $" %8.0fc a5[1,6]/*
				*/ _newline as text " Other family, no <18      {c |}" as result "   $" %8.0fc c0[1,7] "   $" %8.0fc a1[1,7] "   $" %8.0fc a3[1,7] "   $" %8.0fc a4[1,7] "   $" %8.0fc a5[1,7]/*
				*/ _newline as text " Other family, with <18    {c |}" as result "   $" %8.0fc c0[1,8] "   $" %8.0fc a1[1,8] "   $" %8.0fc a3[1,8] "   $" %8.0fc a4[1,8] "   $" %8.0fc a5[1,8]/*
				*/ _newline as text " Multi family, no <18      {c |}" as result "   $" %8.0fc c0[1,9] "   $" %8.0fc a1[1,9] "   $" %8.0fc a3[1,9] "   $" %8.0fc a4[1,9] "   $" %8.0fc a5[1,9]/*
				*/ _newline as text " Multi family, with <18    {c |}" as result "   $" %8.0fc c0[1,10] "   $" %8.0fc a1[1,10] "   $" %8.0fc a3[1,10] "   $" %8.0fc a4[1,10] "   $" %8.0fc a5[1,10]/*
				*/ _newline as text "{hline 27}{c +}{hline 75}"  /*
				*/ _newline as text " Average                   {c |}" as result "   $" %8.0fc c0[1,11] "   $" %8.0fc a1[1,11] "   $" %8.0fc a3[1,11] "   $" %8.0fc a4[1,11] "   $" %8.0fc a5[1,11]

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "IMPACT OF REFORMS IN CASH TERMS ACROSS HOUSEHOLDS USING `Y' AS THE MEASURE OF LIVING STANDARDS FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline 		"    Decile                 {c |}" %~15s "`Y'" %~10s "Net income" %~10s "IVA" %~8s "IEPS" %~14s "TOTAL" /*
				*/ _newline "{hline 27}{c +}{hline 65}"  /*
				*/ _newline as text " Couple                    {c |}" as result "   $" %8.0fc c0[1,1] "   " %6.2fc b1[1,1] "%   " %6.2fc b3[1,1] "%   " %6.2fc b4[1,1] "%   " %6.2fc b5[1,1] "%   " /*
				*/ _newline as text " Single                    {c |}" as result "   $" %8.0fc c0[1,2] "   " %6.2fc b1[1,2] "%   " %6.2fc b3[1,2] "%   " %6.2fc b4[1,2] "%   " %6.2fc b5[1,2] "%   "/*
				*/ _newline as text " Couple, children <18      {c |}" as result "   $" %8.0fc c0[1,3] "   " %6.2fc b1[1,3] "%   " %6.2fc b3[1,3] "%   " %6.2fc b4[1,3] "%   " %6.2fc b5[1,3] "%   "/*
				*/ _newline as text " Single, children <18      {c |}" as result "   $" %8.0fc c0[1,4] "   " %6.2fc b1[1,4] "%   " %6.2fc b3[1,4] "%   " %6.2fc b4[1,4] "%   " %6.2fc b5[1,4] "%   "/*
				*/ _newline as text " Pensioner, single         {c |}" as result "   $" %8.0fc c0[1,5] "   " %6.2fc b1[1,5] "%   " %6.2fc b3[1,5] "%   " %6.2fc b4[1,5] "%   " %6.2fc b5[1,5] "%   "/*
				*/ _newline as text " Pensioner, couple         {c |}" as result "   $" %8.0fc c0[1,6] "   " %6.2fc b1[1,6] "%   " %6.2fc b3[1,6] "%   " %6.2fc b4[1,6] "%   " %6.2fc b5[1,6] "%   "/*
				*/ _newline as text " Other family, no <18      {c |}" as result "   $" %8.0fc c0[1,7] "   " %6.2fc b1[1,7] "%   " %6.2fc b3[1,7] "%   " %6.2fc b4[1,7] "%   " %6.2fc b5[1,7] "%   "/*
				*/ _newline as text " Other family, with <18    {c |}" as result "   $" %8.0fc c0[1,8] "   " %6.2fc b1[1,8] "%   " %6.2fc b3[1,8] "%   " %6.2fc b4[1,8] "%   " %6.2fc b5[1,8] "%   "/*
				*/ _newline as text " Multi family, no <18      {c |}" as result "   $" %8.0fc c0[1,9] "   " %6.2fc b1[1,9] "%   " %6.2fc b3[1,9] "%   " %6.2fc b4[1,9] "%   " %6.2fc b5[1,9] "%   "/*
				*/ _newline as text " Multi family, with <18    {c |}" as result "   $" %8.0fc c0[1,10] "   " %6.2fc b1[1,10] "%   " %6.2fc b3[1,10] "%   " %6.2fc b4[1,10] "%   " %6.2fc b5[1,10] "%   "/*
				*/ _newline as text "{hline 27}{c +}{hline 65}"  /*
				*/ _newline as text " Average                   {c |}" as result "   $" %8.0fc c0[1,11] "   " %6.2fc b1[1,11] "%   " %6.2fc b3[1,11] "%   " %6.2fc b4[1,11] "%   " %6.2fc b5[1,11] "%   "/*
				*/ _newline as text " "/*
				*/ _newline as text " "/*
				*/ _newline as text "{hline 12}{c -}{hline 100}"

				} /* end Q*/
	} /* end Y */

drop tott* totm* num* cashch* propch* totch* ava*

log close

