******************************************************************************************
/*
DISCLAIMER OF WARRANTIES AND LIMITATION OF LIABILITY
The LATAX micro-simulation software written in Stata (from now on the software) 
is supplied as is and all use is at your own risk. The Institute for Fiscal Studies,
the author of, and owner of the intellectual property in, the software disclaims all
warranties of any kind, either express or implied, as to the software, including, 
but not limited to, implied warranties of fitness for a particular purpose, 
merchantability or non-infringement of proprietary rights. 
Neither this agreement nor any documentation furnished under it is intended to express
or imply any warranty that the operation of the software will be uninterrupted, 
timely, or error-free. 
Under no circumstances shall the Institute for Fiscal Studies be liable to any user 
for direct, indirect, incidental, consequential, special, or exemplary damages or losses
of any kind, arising from or relating to this agreement, the software, or users use or 
misuse of the software. Such limitation of liability shall apply whether the damages arise 
from the use or misuse of the software (including such damages incurred by third parties),
or errors of the software.
The original software remains the intellectual property of the Institute for Fiscal Studies
and is made freely available for non-commercial use only. The Institute for Fiscal Studies 
retains sole rights to commercial use of the software and does not authorise commercial 
users to edit, adapt or add to the software. Non-commercial users are authorised to edit, 
adapt and add to the original software in order to make changes to its functionalities. 
However, all of the above disclaimers for liability and any warranties of any kind, 
apply with respect to such derivative (edited, adapted or expanded) versions 
of the software.
By using this software, the user agrees with, and undertakes to abide by, the above 
terms and conditions.
*/

******************************************************************************************

clear all
cap log close
/* Note:  set this so that there is sufficient memory to handle the input files */ 
/* Nota: establecer esto para que haya memoria suficiente para manejar los archivos de entrada*/
set mem 400m  
set more off

program simulator

	do "$taxsim\loadprogs.do"

end


/** MAIN PROGRAM **/
program set_defaults

* Instructions													* Instrucciones

* 1. assign the program directory.								* 1. Asignar el directorio del programa
* 2. assign the input, output, and parameter directories.		* 2. Asignar la entrada, salida y directorios de parmetros
* 3. assign the names of the logfiles.							* 3. Asignar los nombres del "logfiles".
* 4. assign the names of the input dataset.						* 4. Asignar los nombres del conjunto de datos de entrada.
* 5. assign the names of the output datasets.					* 5. Asignar los nombres de los conjuntos de datos de salida.

* Assign default directories
* Asignar directorios predeterminados
global taxsim 	"G:\ET\Mexico\mextax\LATAX@2\Do_Files"  											/****1****/
global in 		"G:\ET\Mexico\mextax\LATAX@2\Input_Data"   										/****2****/
global out 		"G:\ET\Mexico\mextax\LATAX@2\Output_Data" 											/****2****/
global param 	"G:\ET\Mexico\mextax\LATAX@2\Params_Data" 											/****2****/

* Assign default log files
* Asignar "logfiles"
global logfiledecile "decile_practise.txt"										/****3****/
global logfiledecile1 "decileburden_practise.txt"								/****3****/
global logfilehhtype "hhtype_practise.txt" 										/****3****/
global logfilerevenue "revenue_practise.txt"                                    /****3****/

* Assign default input and output files
* Asignacin de archivos por defecto de entrada y salida de archivos
global indata_hh "household"	                                      		/****4****/
global indata_ad "adult"	                                      		/****4****/
global indata_co "consumption_monetary"	                                      		/****4****/

global outdata_ad  "Output_adlevel_practise"                               		/****5****/
global outdata_hh  "Output_hhlevel_practise"									/****5****/


/*** CONTROL VARIABLES ***/

* 1 = full range of distributional analyses, 2 = reduced range
global disttype = 1

* 1 = use calculated net income, 2 = use net income from input data *
global netincometype = 2

* Set the Household Identifier List

global identlist "folioviv foliohog"

/*** MODULES INCLUDING BEHAVIORAL RESPONSE MARGINS ***/


/*** 1)  LABOR SUPPLY MODEL ***/

* do you want to run labor model (1 = Yes, 2 = No)
* DEFAULT SET TO 2 (NO)

global labmod = 1

* Others

global logfilelabor "labor_practise.txt"


/*** 2) CONSUMPTION MODEL ***/

* do you want to run consumption model? (1 = Yes, 2 = No)
* DEFAULT SET TO 2 (NO)

global consmod = 1

* do you want to reduce spending in response to changes in direct taxes? (1 = Yes, 2 = No)

global inc_aff_spend = 1

* Others

global indata_demand "demand_params.dta"
global indata_prices "demand_prices.dta"

global logfiledemand_welfare "decile_demand_practise.txt"
global logfiledemand_spending "spending_demand_practise.txt"
global logfiledemand_revenue "revenue_demand_practise.txt"

global NUMGOODSQUAIDS = 12

global NUMGOODSDEM "1 3 4 6 7 8 9 10 11 12 13 14 15 16 17 19 20 21 22 23 24 25 26 27 28 29 30 31 33 34 36 37 38 39 40 41 42 43 44 45 46 47 49 50 51 52 53 54 55 56 57 58 59 60"

global goodslist1 "8 14 38 44"
global goodslist2 "15 45"
global goodslist3 "26 27 28 29 30 56 57 58 59 60"
global goodslist4 "21 51"
global goodslist5 "16 25 46 55"
global goodslist6 "7 10 37 40"
global goodslist7 "20 24 50 54"
global goodslist8 "4 34"
global goodslist9 "1 9 12 31 39 42"
global goodslist10 "13 17 23 43 47 53"
global goodslist11 "3 6 11 19 33 36 41 49"
global goodslist12 "22 52"


global goodslist13 "2 5 18 32 35 48"

# delimit ;

global categslist1 "9"  ; global categslist2 "13"  ; global categslist3 "11"  ; global categslist4 "8"  ; global categslist5 "13"  ; global categslist6 "11"  ;
global categslist7 "6"  ; global categslist8 "1"   ; global categslist9 "9"   ; global categslist10 "6" ; global categslist11 "11" ; global categslist12 "9"  ;
global categslist13 "10"; global categslist14 "1"  ; global categslist15 "2"  ; global categslist16 "5" ; global categslist17 "10" ; global categslist18 "13" ;
global categslist19 "11"; global categslist20 "7"  ; global categslist21 "4"  ; global categslist22 "12"; global categslist23 "10" ; global categslist24 "7"  ;
global categslist25 "5" ; global categslist26 "3"  ; global categslist27 "3"  ; global categslist28 "3" ; global categslist29 "3"  ; global categslist30 "3"  ;

global categslist31 "9" ; global categslist32 "13" ; global categslist33 "11" ; global categslist34 "8" ; global categslist35 "13" ; global categslist36 "11" ;
global categslist37 "6" ; global categslist38 "1"  ; global categslist39 "9"  ; global categslist40 "6" ; global categslist41 "11" ; global categslist42 "9"  ;
global categslist43 "10"; global categslist44 "1"  ; global categslist45 "2"  ; global categslist46 "5" ; global categslist47 "10" ; global categslist48 "13" ;
global categslist49 "11"; global categslist50 "7"  ; global categslist51 "4"  ; global categslist52 "12"; global categslist53 "10" ; global categslist54 "7"  ;
global categslist55 "5" ; global categslist56 "3"  ; global categslist57 "3"  ; global categslist58 "3" ; global categslist59 "3"  ; global categslist60 "3"  ;

# delimit cr

***************************


/*** 3) INDIRECT TAX INCIDENCE ***/

* do you want to estimate distributional effects with alternate pass-through assumptions for Indirect Tax? (1 = Yes, 2 = No)
* DEFAULT SET TO 2 (NO)

global indir = 1

* proportion of pass-through
global prop_prices = 0.75

* proportion not passed through borne by wages
global prop_wages  = 0.75

* output data for the different pass-through of indirect tax
global outdata_ad_ind "out_adlevel_ind_p75_w75_practise"
global logfiledecile_ind "decile_ind_p75_w75_practise.txt"
global logfilehhtype_ind "hhtype_ind_p75_w75_practise.txt"
global logfilerevenue_ind "revenue_ind_p75_w75_practise.txt"

* control parameter (don't change)
global indic_incidence = 1


end




/***************************/
/********* OPTIONS *********/
/***************************/

/** COMPULSORY OPTIONS **/

program set_country

	version 11
	syntax anything

	global country `anything'


end

program set_systems

	version 11

	global sys1 = `1'
	global sys2 = `2'
	global sys3 = `3'


end

/** OPTIONAL OPTIONS **/

*** TURN OPTIONS ON AND OFF ***

program set_disttype

	version 11

	global disttype = `1'

end

program set_netinctype

	version 11

	global netincometype = `1'

end

program set_labmod

	version 11

	global labmod = `1'

end

program set_consmod

	version 11

	global consmod = `1'

end


program set_indir

	version 11

	global indir = `1'

end

*** CHANGE DIRECTORIES ***

program set_progdir

	version 11
	syntax anything

	global taxsim 	`anything'

end


program set_inputdir

	version 11
	syntax anything

	global in 		`anything'

end

program set_outputdir

	version 11
	syntax anything

	global out 		`anything'

end

program set_paramdir

	version 11
	syntax anything

	global param 	`anything'

end

*** CHANGE STATA FILE NAMES ***

program set_consdat

	version 11
	syntax anything

	global indata_co	`anything'

end

program set_addat

	version 11
	syntax anything

	global indata_ad	`anything'

end

program set_hhdat

	version 11
	syntax anything

	global indata_hh 	`anything'

end

program set_adout

	version 11
	syntax anything

	global outdata_ad	`anything'

end

program set_hhout

	version 11
	syntax anything

	global outdata_hh 	`anything'

end

*** CHANGE LOG FILE NAMES ***

program set_logdec

	version 11
	syntax anything

	global logfiledecile	`anything'

end

program set_logbur

	version 11
	syntax anything

	global logfiledecile1	`anything'

end

program set_loghh

	version 11
	syntax anything

	global logfilehhtype 	`anything'

end

program set_logrev

	version 11
	syntax anything

	global logfilerevenue	`anything'

end

*** CHANGE LABOUR MOD OPTIONS ***

program set_labout

	version 11
	syntax anything

	global logfilelabor	`anything'

end

*** CHANGE DEMAND MOD OPTIONS ***

program set_changewithinc

	version 11

	global inc_aff_spend = `1'

end

program set_demandparam

	version 11
	syntax anything

	global indata_demand	`anything'

end

program set_demandprice

	version 11
	syntax anything

	global indata_prices	`anything'

end

program set_demandwelfare

	version 11
	syntax anything

	global logfiledemand_welfare	`anything'

end

program set_demandspending

	version 11
	syntax anything

	global logfiledemand_spending	`anything'

end

program set_demandrevenue

	version 11
	syntax anything

	global logfiledemand_revenue	`anything'

end


*** CHANGE INDIRECT INCIDENCE MOD OPTIONS ***

program set_propprices

	version 11

	global prop_prices = `1'

end


program set_propwages

	version 11

	global prop_wages = `1'

end

program set_adout_ind

	version 11
	syntax anything

	global outdata_ad_ind	`anything'

end

program set_logdec_ind

	version 11
	syntax anything

	global logfiledecile_ind 	`anything'

end

program set_loghh_ind

	version 11
	syntax anything

	global logfilehhtype_ind	`anything'

end

program set_logrev_ind

	version 11
	syntax anything

	global logfilerevenue_ind	`anything'

end
