*******************************************************************************************************
* Latin-TAXBEN - The Flexible Tax Simulator for Middle Income Countries
* Build 2012-1
* 
* Program name / Nombre del programa : quaids.do
*
* Program purpose: This program uses parameters from our estimated demand model to calculate welfare effects of
*			 changes in taxes accounting for substitution between goods
*
* Objetivo del Programa: Este programa utiliza los parmetros de nuestro modelo de demanda estimada para calcular
*				 los efectos de bienestar de los cambios en los impuestos de contabilidad para la 
*				 sustitucin entre bienes

* Notes:			 At the moment based on within-group additive weighted average price indices			
*				 Prices in the baseline are taken as the prices from the BoM data

*
* Program created: 22 Feb 2011, by David Phillips
* Program updated: 07 Mar 2011, by David Phillips
* Program updated: 29 May 2012, by David Phillips (based on MEXTAX 2010 Build)
** Programa actualizado: 29 May 2012, por David Phillips
*******************************************************************************************************
cap log close
set logtype text
use "$in\\$indata_co", clear

* MERGE SPENDING PRE REFORMS *

sort folioviv foliohog numren

merge folioviv foliohog numren using "$out//indir_$sys1"

tab _merge
drop _merge

sort folioviv foliohog numren
merge folioviv foliohog numren using "$in\\$indata_hh", keep(factor totexp eqsc_8050)

tab _merge
keep if _merge==3
drop _merge

gen totexp_eq = totexp/eqsc_8050
xtile decile = totexp_eq [fw=factor], nq(10) 

* SET UP GOODS CATEGORIES, TOTALS AND SHARES *

local z "$NUMGOODSDEM"
local zz = $NUMGOODSQUAIDS
local zzz = 60
local zzzz = `zz' - 1
local zzzzz = `zz' + 1

global dems "child adult sex empstat educlow educmid v1 v2 v3 v4 v5 v6 central north_interior north_coastal west east south south_east " 

gen spending = 0

foreach X in `z' {

	replace spending = spending + nexp`X'_$sys1

}

/*
foreach X of numlist (`zz'+1)(1)(`zz'+1) {

	local x "`X'"
	local y "goodslist`y'"

	foreach Z in $`y' {

		replace spending = spending - nexp`Z'_$sys1

	}
}
*/

foreach X in `z' {

	gen expshare`X' =  nexp`X'_$sys1/spending

}

foreach X of numlist 1(1)`zz' {

	gen spending`X' = 0

}

foreach X of numlist 1(1)`zz' {

	local x "`X'"
	local y "goodslist`x'"

	foreach Z in $`y' {

		replace spending`X' = spending`X' + nexp`Z'_$sys1

	}

}

foreach X of numlist 1(1)`zz' {

	egen sumspending`X' = sum(spending`X'*factor), by(region decile)

}

* MERGE PARAMETER AND PRICES FILES *

gen merger = 1
cap drop _merge
sort merger 

*merge merger using $in\\$indata_demand
merge m:m merger using $in\\$indata_demand

tab _merge
drop _merge

sort folioviv foliohog 

merge folioviv foliohog using $in\\$indata_prices

tab _merge
drop _merge

* SET UP PRICE INDICES FOR THE CALCULATION OF UTILITIES *

gen alfa_not = 2.299803

gen lnap = alfa_not 

foreach X of numlist 1(1)`zz' {

		gen oa`X' = a`X'

	*foreach Y in child adult sex empstat educlow educmid v1 v2 v3 v4 v5 v6 central north_interior north_coastal west east south south_east {
	foreach Y in $dems {
		replace a`X' = a`X' + w`X'_`Y'*`Y'
	
	}
}	

foreach X of numlist 1(1)`zz' {

	replace lnap = lnap + (a`X'*lnp`X')

}

foreach X of numlist 1(1)`zz' {

	foreach Y of numlist 1(1)`zz' {

		replace lnap = lnap + (0.5*b`X'_`Y'*lnp`X'*lnp`Y')

	}
}

gen ap = exp(lnap)

gen bp = 1

foreach X of numlist 1(1)`zz' {

	replace bp = bp*(p`X'^c`X')

}

gen lamda_p = 0

foreach X of numlist 1(1)`zz' {

	replace lamda_p = lamda_p + (d`X'*lnp`X')

} 

** convert spending to monthly equivalised amounts as used in demand model **

gen lnm = ln(spending/(eqsc_8050*12))

* CALCULATE INITIAL UTILITY AS BASIS FOR CALCULTING WELFARE EFFECTS *   

gen lnv = (lnm - lnap)/bp
replace lnv = (1/lnv) + lamda_p
replace lnv = 1/lnv

** check obtain original lnm when re-invert

gen lnc = lnap + bp*(((1/lnv) - lamda_p)^(-1))


*assert lnm == lnc

* PREDICT SHARES FOR EACH GOOD *

foreach X of numlist 1(1)`zzzz' {

	gen w`X' = oa`X'

	foreach Y of numlist 1(1)`zz' {

		replace w`X' = w`X' + lnp`Y'*b`X'_`Y'
	}

	replace w`X' = w`X' + (lnm-lnap)*c`X' + ((lnm - lnap)^2)*d`X'/bp

	foreach Y in $dems {
	
		replace w`X' = w`X' + w`X'_`Y'*`Y'

	}
		
}

gen w`zz' = 1

foreach X of numlist 1(1)`zzzz' {

	replace w`zz' = w`zz' - w`X'

}

* CONVERT PREDICTED SHARES FOR EACH GOOD INTO PREDICTED SPENDING *

foreach X of numlist 1(1)`zz' {

	gen pred`X' = w`X'*spending

}

foreach X of numlist 1(1)`zz' {

	rename p`X' op`X'
	rename lnp`X' olnp`X' 
	gen p`X' = 0
	gen lnp`X' = 0

} 

/* PERHAPS INSERT BIT HERE WHICH ADJUSTS BASELINE BY ADDING BACK IN ERROR
WITH THE ASSUMPTION THAT THE PREDICTION ERROR IS SAME WHEN PRICES DIFFER */

********************************************************************

* MERGE SPENDING POST REFORMS *

sort folioviv foliohog numren

merge folioviv foliohog numren using "$out//indir_$sys2"

tab _merge
keep if _merge==3
drop _merge

sort folioviv foliohog numren

merge folioviv foliohog numren using "$out//indir_$sys3"

tab _merge
keep if _merge==3
drop _merge

* SET UP GOODS CATEGORIES, TOTALS AND SHARES *

local z "$NUMGOODSDEM"
local zz = $NUMGOODSQUAIDS
local zzz = 60

foreach Y in $sys2 $sys3 {

	gen spending_`Y' = 0

	foreach X in `z' {

		replace spending_`Y' = spending_`Y' + nexp`X'_`Y'

	}


	foreach X in `z' {

		gen expshare`X'_`Y' =  nexp`X'_`Y'/spending_`Y'

	}

foreach X of numlist 1(1)`zz' {

	gen spending`X'_`Y' = 0

}

foreach X of numlist 1(1)`zz' {

	local x "`X'"
	local y "goodslist`x'"

	foreach Z in $`y' {

		replace spending`X'_`Y' = spending`X'_`Y' + nexp`Z'_`Y'

	}

}

foreach X of numlist 1(1)`zz' {

	egen sumspending`X'_`Y' = sum(spending`X'_`Y'*factor), by(region decile)

}

} /* close Y = $sys */

foreach Y in $sys2 $sys3 {

local q = `Y'

* UPDATE THE PRICE OF GOODS TO ACCOUNT FOR HIGHER TAXES *

	foreach X of numlist 1(1)`zz' {

		replace p`X' = op`X'*(sumspending`X'_`Y'/sumspending`X')
		replace lnp`X' = ln(p`X')
	}

	foreach X of numlist 1(1)`zz' {

		gen changepred`X'_`Y' = ((p`X'-op`X')/op`X')*pred`X'
	}

* SET UP PRICE INDICES FOR THE CALCULATION OF UTILITIES *

	gen lnap`Y' = alfa_not

	foreach X of numlist 1(1)`zz' {

		replace a`X' = oa`X'		

		*foreach Z in child adult sex empstat educlow educmid v1 v2 v3 v4 v5 v6 central north_interior north_coastal west east south south_east {
		foreach Z in $dems {
		
			replace a`X' = a`X' + w`X'_`Z'*`Z'
	
		}
	} 
	
	foreach X of numlist 1(1)`zz' {

		replace lnap`q' = lnap`q' + a`X'*lnp`X'

	}



	foreach X of numlist 1(1)`zz' {

		foreach Z of numlist 1(1)`zz' {

			replace lnap`Y' = lnap`Y' + (0.5*b`X'_`Z'*lnp`X'*lnp`Z')

		}
	}

	gen ap`Y' = exp(lnap`Y')
	gen bp`Y' = 1

	foreach X of numlist 1(1)`zz' {

		replace bp`Y' = bp`Y'*(p`X'^c`X')

	}

	gen lamda_p`Y' = 0

	foreach X of numlist 1(1)`zz' {

		replace lamda_p`Y' = lamda_p`Y' + (d`X'*lnp`X')

	} 

* CALCULATE COMPENSATING VARIATION *

	gen lnc_`Y' = lnap`Y' + bp`Y'*(((1/lnv) - lamda_p`Y')^(-1))
	gen cv`Y'  = (spending/(eqsc_8050*12)) - exp(lnc_`Y')
	replace cv`Y' = cv`Y'*eqsc_8050*12


* CALCULATE THE IMPACT OF PRICE CHANGES IF THERE IS NO BEHAVIOUR *

	gen cv_nob`Y' = 0

	foreach X of numlist 1(1)`zz' {

		replace cv_nob`Y' = cv_nob`Y' - changepred`X'_`Y' 

	}


* INCLUDE THE LOSSES DUE TO OTHER CHANGES IN INDIRECT TAX *

	foreach X of numlist `zzzzz'(1)`zzzzz' {

		local x "`X'"
		local y "goodslist`x'"

		foreach Z in $`y' {

			replace cv`Y' = cv`Y' + (-iva_`Z'_`Y' - ieps_`Z'_`Y' + iva_`Z'_$sys1 + ieps_`Z'_$sys1)
			replace cv_nob`Y' = cv_nob`Y' + (-iva_`Z'_`Y' - ieps_`Z'_`Y' + iva_`Z'_$sys1 + ieps_`Z'_$sys1)

		}

	}
	

} /* end Y = $sys LOOP */

* MERGE DATA ON HOUSEHOLD CHARACTERISTICS AND SET UP FOR OUTPUT OF TABLES *

sort folioviv foliohog numren

merge folioviv foliohog numren using "$out\\$outdata_hh", keep(hhnet* hhtype eqsc_5030 eqsc_8050 eqsc_100100 totexp monexp totinc moninc factor)

rename eqsc_100100 eqsc11
rename eqsc_8050 eqsc85
rename eqsc_5030 eqsc53

qui {

********************************************************
***************** WELFARE ANALYSIS *********************
********************************************************

foreach X in eqsc11 eqsc85 eqsc53 {

	foreach Y of varlist totexp monexp totinc moninc {

		gen `Y'_`X' = `Y'/`X'
		xtile dec`Y'_`X' = `Y'_`X' [fw=factor], nq(10)

	}
}
} /* end quietly */

capture program drop log_distanalysis
program define log_distanalysis 	

log using "$out//$logfiledemand_welfare", replace

**** DISTRIBUTION OF LIVING STANDARDS (INCOME / SPENDING) ****

foreach X in eqsc11 eqsc85 eqsc53 {

	foreach Y of varlist totexp totinc {
		
		qui {

				egen tot`Y'_`X' = sum(`Y'*factor), by(dec`Y'_`X')
				egen num`Y'_`X' = sum(factor), by(dec`Y'_`X')
				gen ava`Y'_`X' = tot`Y'_`X'/num`Y'_`X'

		foreach Z in $sys2 $sys3 {

			foreach W in cv cv_nob {

				egen tot`W'`Z'_`Y'`X' = sum(`W'`Z'*factor), by(dec`Y'_`X')
				gen cash`W'`Z'_`Y'`X' = tot`W'`Z'_`Y'`X'/num`Y'_`X' 
				gen prop`W'`Z'_`Y'`X' = 100*tot`W'`Z'_`Y'`X'/tot`Y'_`X' 


			}	
		}
		} /* qui */
		
		qui tabstat ava`Y'_`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`Y'_`X') save
		matrix c0 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))		

foreach Q in $sys2 $sys3 {
	qui {
			local Z = `Q'
		
			qui tabstat cashcv`Z'_`Y'`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`Y'_`X') save
			matrix a1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propcv`Z'_`Y'`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`Y'_`X') save
			matrix b1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashcv_nob`Z'_`Y'`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`Y'_`X') save
			matrix a2 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propcv_nob`Z'_`Y'`X' [fw=factor], stats(mean) f(%20.0fc) by(dec`Y'_`X') save
			matrix b2 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

	}		/*end qui */
	
			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "IMPACT OF REFORMS IN CASH TERMS USING DECILES OF `Y' USING EQUIVALENCE SCALE `X' FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline "    Decile  {c |}" %~13s "`Y'" %~17s "With Behavior" %~18s "Without Behavior"  /*
				*/ _newline "{hline 12}{c +}{hline 50}"  /*
				*/ _newline as text " Poorest    {c |}" as result "   $" %8.0fc c0[1,1] "      $" %8.0fc a1[1,1] "       $" %8.0fc a2[1,1] /*
				*/ _newline as text " Decile 2   {c |}" as result "   $" %8.0fc c0[1,2] "      $" %8.0fc a1[1,2] "       $" %8.0fc a2[1,2] /*
				*/ _newline as text " Decile 3   {c |}" as result "   $" %8.0fc c0[1,3] "      $" %8.0fc a1[1,3] "       $" %8.0fc a2[1,3] /*
				*/ _newline as text " Decile 4   {c |}" as result "   $" %8.0fc c0[1,4] "      $" %8.0fc a1[1,4] "       $" %8.0fc a2[1,4] /*
				*/ _newline as text " Decile 5   {c |}" as result "   $" %8.0fc c0[1,5] "      $" %8.0fc a1[1,5] "       $" %8.0fc a2[1,5] /*
				*/ _newline as text " Decile 6   {c |}" as result "   $" %8.0fc c0[1,6] "      $" %8.0fc a1[1,6] "       $" %8.0fc a2[1,6] /*
				*/ _newline as text " Decile 7   {c |}" as result "   $" %8.0fc c0[1,7] "      $" %8.0fc a1[1,7] "       $" %8.0fc a2[1,7] /*
				*/ _newline as text " Decile 8   {c |}" as result "   $" %8.0fc c0[1,8] "      $" %8.0fc a1[1,8] "       $" %8.0fc a2[1,8] /*
				*/ _newline as text " Decile 9   {c |}" as result "   $" %8.0fc c0[1,9] "      $" %8.0fc a1[1,9] "       $" %8.0fc a2[1,9] /*
				*/ _newline as text " Richest    {c |}" as result "   $" %8.0fc c0[1,10] "      $" %8.0fc a1[1,10] "       $" %8.0fc a2[1,10] /*
				*/ _newline as text "{hline 12}{c +}{hline 50}"  /*
				*/ _newline as text " Average    {c |}" as result "   $" %8.0fc c0[1,11] "      $" %8.0fc a1[1,11] "       $" %8.0fc a2[1,11]
				
			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "IMPACT OF REFORMS IN PROPORTIONAL TERMS USING DECILES OF `Y' USING EQUIVALENCE SCALE `X' FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline "    Decile  {c |}" %~13s "`Y'" %~17s "With Behavior" %~18s "Without Behavior"  /*
				*/ _newline "{hline 12}{c +}{hline 50}"  /*
				*/ _newline as text " Poorest    {c |}" as result "   $" %8.0fc c0[1,1] "      " %6.2fc b1[1,1] "%        " %6.2fc b2[1,1] "%    " /*
				*/ _newline as text " Decile 2   {c |}" as result "   $" %8.0fc c0[1,2] "      " %6.2fc b1[1,2] "%        " %6.2fc b2[1,2] "%    " /*
				*/ _newline as text " Decile 3   {c |}" as result "   $" %8.0fc c0[1,3] "      " %6.2fc b1[1,3] "%        " %6.2fc b2[1,3] "%    " /*
				*/ _newline as text " Decile 4   {c |}" as result "   $" %8.0fc c0[1,4] "      " %6.2fc b1[1,4] "%        " %6.2fc b2[1,4] "%    " /*
				*/ _newline as text " Decile 5   {c |}" as result "   $" %8.0fc c0[1,5] "      " %6.2fc b1[1,5] "%        " %6.2fc b2[1,5] "%    " /*
				*/ _newline as text " Decile 6   {c |}" as result "   $" %8.0fc c0[1,6] "      " %6.2fc b1[1,6] "%        " %6.2fc b2[1,6] "%    " /*
				*/ _newline as text " Decile 7   {c |}" as result "   $" %8.0fc c0[1,7] "      " %6.2fc b1[1,7] "%        " %6.2fc b2[1,7] "%    " /*
				*/ _newline as text " Decile 8   {c |}" as result "   $" %8.0fc c0[1,8] "      " %6.2fc b1[1,8] "%        " %6.2fc b2[1,8] "%    " /*
				*/ _newline as text " Decile 9   {c |}" as result "   $" %8.0fc c0[1,9] "      " %6.2fc b1[1,9] "%        " %6.2fc b2[1,9] "%    " /*
				*/ _newline as text " Richest    {c |}" as result "   $" %8.0fc c0[1,10] "      " %6.2fc b1[1,10] "%       " %6.2fc b2[1,10] "%    " /*
				*/ _newline as text "{hline 12}{c +}{hline 50}"  /*
				*/ _newline as text " Average    {c |}" as result "   $" %8.0fc c0[1,11] "      " %6.2fc b1[1,11] "%       " %6.2fc b2[1,11] "%    " /*	
				*/ _newline as text " "/*
				*/ _newline as text " "/*
				*/ _newline as text "{hline 12}{c -}{hline 100}"
				

	} /* end Q*/		
	} /* end Y */
} 	  /* end X */



**** DISTRIBUTION ACROSS HOUSEHOLD TYPES ****

	foreach Y of varlist totexp totinc {
		
		qui {

				egen tot`Y' = sum(`Y'*factor), by(hhtype)
				egen num`Y' = sum(factor), by(hhtype)
				gen ava`Y' = tot`Y'/num`Y'
				

		foreach Z in $sys2 $sys3 {

			foreach W in cv cv_nob {

				egen tot`W'`Z'_`Y' = sum(`W'`Z'*factor), by(hhtype)
				gen cash`W'`Z'_`Y' = tot`W'`Z'_`Y'/num`Y'
				gen prop`W'`Z'_`Y' = 100*tot`W'`Z'_`Y'/tot`Y' 


			}	/* end W */
		} 		/* end z */
		} 		/* end qui */

		qui tabstat ava`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
		matrix c0 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10))		

foreach Q in $sys2 $sys3 {
	qui {
			local Z = `Q'
		
			qui tabstat cashcv`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix a1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propcv`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix b1 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

			qui tabstat cashcv_nob`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix a2 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))
			qui tabstat propcv_nob`Z'_`Y' [fw=factor], stats(mean) f(%20.0fc) by(hhtype) save
			matrix b2 = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10), r(StatTotal))

	}		/*end qui */
	
			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "IMPACT OF REFORMS IN CASH TERMS ACROSS HOUSEHOLDS USING `Y' AS THE MEASURE OF LIVING STANDARDS FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline "    HHType                 {c |}" %~13s "`Y'" %~17s "With Behavior" %~18s "Without Behavior"  /*
				*/ _newline "{hline 27}{c +}{hline 50}"  /*
				*/ _newline as text " Couple                    {c |}" as result "   $" %8.0fc c0[1,1] "      $" %8.0fc a1[1,1] "       $" %8.0fc a2[1,1] /*
				*/ _newline as text " Single                    {c |}" as result "   $" %8.0fc c0[1,2] "      $" %8.0fc a1[1,2] "       $" %8.0fc a2[1,2] /*
				*/ _newline as text " Couple, children <18      {c |}" as result "   $" %8.0fc c0[1,3] "      $" %8.0fc a1[1,3] "       $" %8.0fc a2[1,3] /*
				*/ _newline as text " Single, children <18      {c |}" as result "   $" %8.0fc c0[1,4] "      $" %8.0fc a1[1,4] "       $" %8.0fc a2[1,4] /*
				*/ _newline as text " Pensioner, single         {c |}" as result "   $" %8.0fc c0[1,5] "      $" %8.0fc a1[1,5] "       $" %8.0fc a2[1,5] /*
				*/ _newline as text " Pensioner, couple         {c |}" as result "   $" %8.0fc c0[1,6] "      $" %8.0fc a1[1,6] "       $" %8.0fc a2[1,6] /*
				*/ _newline as text " Other family, no <18      {c |}" as result "   $" %8.0fc c0[1,7] "      $" %8.0fc a1[1,7] "       $" %8.0fc a2[1,7] /*
				*/ _newline as text " Other family, with <18    {c |}" as result "   $" %8.0fc c0[1,8] "      $" %8.0fc a1[1,8] "       $" %8.0fc a2[1,8] /*
				*/ _newline as text " Multi family, no <18      {c |}" as result "   $" %8.0fc c0[1,9] "      $" %8.0fc a1[1,9] "       $" %8.0fc a2[1,9] /*
				*/ _newline as text " Multi family, with <18    {c |}" as result "   $" %8.0fc c0[1,10] "      $" %8.0fc a1[1,10] "       $" %8.0fc a2[1,10] /*
				*/ _newline as text "{hline 27}{c +}{hline 50}"  
				
			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "IMPACT OF REFORMS IN CASH TERMS ACROSS HOUSEHOLDS USING `Y' AS THE MEASURE OF LIVING STANDARDS FOR REFORM SYSTEM " `Q' /*
				*/ _newline "" /*
				*/ _newline "    HHType                 {c |}" %~13s "`Y'" %~17s "With Behavior" %~18s "Without Behavior"  /*
				*/ _newline "{hline 27}{c +}{hline 50}"  /*
				*/ _newline as text " Couple                    {c |}" as result "   $" %8.0fc c0[1,1] "      " %6.2fc b1[1,1] "%        " %6.2fc b2[1,1] "%    " /*
				*/ _newline as text " Single                    {c |}" as result "   $" %8.0fc c0[1,2] "      " %6.2fc b1[1,2] "%        " %6.2fc b2[1,2] "%    " /*
				*/ _newline as text " Couple, children <18      {c |}" as result "   $" %8.0fc c0[1,3] "      " %6.2fc b1[1,3] "%        " %6.2fc b2[1,3] "%    " /*
				*/ _newline as text " Single, children <18      {c |}" as result "   $" %8.0fc c0[1,4] "      " %6.2fc b1[1,4] "%        " %6.2fc b2[1,4] "%    " /*
				*/ _newline as text " Pensioner, single         {c |}" as result "   $" %8.0fc c0[1,5] "      " %6.2fc b1[1,5] "%        " %6.2fc b2[1,5] "%    " /*
				*/ _newline as text " Pensioner, couple         {c |}" as result "   $" %8.0fc c0[1,6] "      " %6.2fc b1[1,6] "%        " %6.2fc b2[1,6] "%    " /*
				*/ _newline as text " Other family, no <18      {c |}" as result "   $" %8.0fc c0[1,7] "      " %6.2fc b1[1,7] "%        " %6.2fc b2[1,7] "%    " /*
				*/ _newline as text " Other family, with <18    {c |}" as result "   $" %8.0fc c0[1,8] "      " %6.2fc b1[1,8] "%        " %6.2fc b2[1,8] "%    " /*
				*/ _newline as text " Multi family, no <18      {c |}" as result "   $" %8.0fc c0[1,9] "      " %6.2fc b1[1,9] "%        " %6.2fc b2[1,9] "%    " /*
				*/ _newline as text " Multi family, with <18    {c |}" as result "   $" %8.0fc c0[1,10] "      " %6.2fc b1[1,10] "%       " %6.2fc b2[1,10] "%    " /*
				*/ _newline as text "{hline 27}{c +}{hline 50}"  /*
				*/ _newline as text " "/*
				*/ _newline as text " "/*
				*/ _newline as text "{hline 27}{c -}{hline 100}"
				

	} /* end Q*/		
	} /* end Y */

drop tottot* num* 

end

log_distanalysis

log close

*****************************************************************
***************** SPENDING PATTERN ANALYSIS *********************
*****************************************************************

foreach Y in $sys2 $sys3 {

	foreach X of numlist 1(1)`zz' {

		replace p`X' = op`X'*(sumspending`X'_`Y'/sumspending`X')
		replace lnp`X' = ln(p`X')

	}

* STANDARD ANALYSIS WHERE LOWER NET INCOME DOES NOT AFFECT SPENDING AMOUNT OR PATTERNS *

	if $inc_aff_spend == 2 {

* RE-ESTIMATE SHARES FOR EACH GOOD *

		foreach X of numlist 1(1)`zzzz' {

			replace a`X' = oa`X'

			gen w`X'_`Y' = a`X'

			foreach Z of numlist 1(1)`zz' {

				replace w`X'_`Y' = w`X'_`Y' + lnp`Z'*b`X'_`Z'
			}

			replace w`X'_`Y' = w`X'_`Y' + (lnm-lnap`Y')*c`X' + ((lnm - lnap`Y')^2)*d`X'/bp`Y'

			foreach Z in $dems {
	
				replace w`X'_`Y' = w`X'_`Y' + w`X'_`Z'*`Z'

			}
		}

		gen w`zz'_`Y' = 1

		foreach X of numlist 1(1)`zzzz' {

			replace w`zz'_`Y' = w`zz'_`Y' - w`X'_`Y'

		}

	} /* end inc_aff_spend LOOP */

* IF WISH TO LOOK AT IMPACT OF LOWER NET INCOME ON SPENDING PATTERNS UNDER ASSUMPTION *
* THAT TOTAL MONETARY SPENDING FALLS BY THE SAME PROPORTION AS MONETARY NET INCOME *

	if $inc_aff_spend == 1 {

		gen lnm_`Y' = ln((spending/(eqsc85*12))*hhnet`Y'/hhnet$sys1)

	* RE-ESTIMATE SHARES FOR EACH GOOD *

		foreach X of numlist 1(1)`zzzz' {

			replace a`X' = oa`X'
			
			gen w`X'_`Y' = a`X'

			foreach Z of numlist 1(1)`zz' {

				replace w`X'_`Y' = w`X'_`Y' + lnp`Z'*b`X'_`Z'
			}

			replace w`X'_`Y' = w`X'_`Y' + (lnm_`Y'-lnap`Y')*c`X' + ((lnm_`Y' - lnap`Y')^2)*d`X'/bp`Y'
			
			foreach Z in $dems {
	
				replace w`X'_`Y' = w`X'_`Y' + w`X'_`Z'*`Z'

			}
		}

		gen w`zz'_`Y' = 1

		foreach X of numlist 1(1)`zzzz' {

			replace w`zz'_`Y' = w`zz'_`Y' - w`X'_`Y'

		}

	} /* end inc_aff_spend LOOP */

} /* end Y = System LOOP */

*gen bob = bobbbbyyyyyyyyyyyyy

/* NOW PRODUCE LOG FILE SHOWING CHANGE IN SPENDING PATTERNS */

	egen total_spending = sum(spending*factor)

foreach Y in $sys2 $sys3 {

	if $inc_aff_spend ==1 {

		gen spending`Y' = spending*hhnet`Y'/hhnet$sys1
	
		egen total_spending_`Y' = sum(spending`Y'*factor)
	
	}
	if $inc_aff_spend == 2 {

		gen spending`Y' = spending

		egen total_spending_`Y' = sum(spending`Y'*factor)

	}
}
	
foreach X of numlist 1(1)`zz' {

** baseline system (predicted)

	egen total_categ`X' = sum(w`X'*spending*factor)
	gen share_categ`X' = total_categ`X'/total_spending

** reform systems (predicted)

	foreach Y in $sys2 $sys3 {

		egen total_categ`X'_`Y' = sum(w`X'_`Y'*spending`Y'*factor)
		gen share_categ`X'_`Y' = total_categ`X'_`Y'/total_spending_`Y'

	}
}	

** log file

	gen sharemean = .
	
	foreach Y in $sys2 $sys3 {
	
		gen sharemean_`Y' = .
	
	}
		

	foreach X of numlist 1(1)`zz' {
		sort folioviv foliohog
		replace sharemean = share_categ`X'*100 if _n==`X'
		
		foreach Y in $sys2 $sys3 {
			sort folioviv foliohog
			replace sharemean_`Y' = share_categ`X'_`Y'*100 if _n==`X'
			
		} /* end Y */

	}	  /* end X */
	
sort folioviv foliohog

gen good = _n if _n<13

local zz = 12

matrix a1 = (1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
matrix a2 = (1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
matrix a3 = (1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)

qui tabstat sharemean if good!=., stats(mean) f(%20.0fc) by(good) save
foreach X of numlist 1(1)`zz' {
	matrix a1[1,`X'] = (r(Stat`X'))
}

qui tabstat sharemean_$sys2 if good!=., stats(mean) f(%20.0fc) by(good) save
foreach X of numlist 1(1)`zz' {
	matrix a2[1,`X'] = (r(Stat`X'))
}

qui tabstat sharemean_$sys3 if good!=., stats(mean) f(%20.0fc) by(good) save
foreach X of numlist 1(1)`zz' {
	matrix a3[1,`X'] = (r(Stat`X'))
}


capture program drop log_spending
program define log_spending 	

local q = $sys2
local r = $sys3

log using "$out//$logfiledemand_spending", replace
local zz = $NUMGOODSQUAIDS
			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~72s "IMPACT OF REFORMS ON SPENDING PATTERNS" /*
				*/ _newline "" /*
				*/ _newline 		"  Commodity Group   {c |}" %~15s "Original" %~10s "   Reform " `q' %~10s "    Reform " `r' /*
				*/ _newline "{hline 20}{c +}{hline 50}"
				
		foreach X of numlist 1(1)9 {
			
			di as text "        " `X' "           {c |}" as result "   " %6.3fc a1[1,`X'] "%          " %6.3fc a2[1,`X'] "%         " %6.3fc a3[1,`X'] "%    "
	
		}
		foreach X of numlist 10(1)`zz' {
			
			di as text "        " `X' "          {c |}" as result "   " %6.3fc a1[1,`X'] "%          " %6.3fc a2[1,`X'] "%         " %6.3fc a3[1,`X'] "%    "
	
		}
			di as text "{hline 20}{c +}{hline 50}"

log close 

end

log_spending

********************************************************
***************** REVENUE ANALYSIS *********************
********************************************************

** Takes revenues at the individual goods levels and multiplies by the ratio of the share post-reform relative to pre-reform
** with adjustment for change in total spending (if thats being modelled)
** Then produces summary of revenue figures 

foreach X of numlist 1(1)`zz' {

	gen multiplier`X'_$sys2 = (share_categ`X'_$sys2/share_categ`X')*(sumspending`X'/sumspending`X'_$sys2)*(total_spending_$sys2/total_spending)
	gen multiplier`X'_$sys3 = (share_categ`X'_$sys3/share_categ`X')*(sumspending`X'/sumspending`X'_$sys2)*(total_spending_$sys3/total_spending)

	gen multiplier`X'n_$sys2 = (sumspending`X'/sumspending`X'_$sys2)*(total_spending_$sys2/total_spending)
	gen multiplier`X'n_$sys3 = (sumspending`X'/sumspending`X'_$sys3)*(total_spending_$sys3/total_spending)

}

gen multiplier`zzzzz'_$sys2 = 1
gen multiplier`zzzzz'_$sys3 = 1

gen multiplier`zzzzz'n_$sys2 = 1
gen multiplier`zzzzz'n_$sys3 = 1

foreach X of numlist 1(1)`zzz' {

	foreach Y in $sys2 $sys3 {

		local x "`X'"
		local y "categslist`x'"

		foreach Z in $`y' {

			replace iva_`X'_`Y' = iva_`X'_`Y'*multiplier`Z'_`Y'
			replace ieps_`X'_`Y' = ieps_`X'_`Y'*multiplier`Z'_`Y'		

			gen iva_`X'_`Y'n = iva_`X'_`Y'*multiplier`Z'n_`Y'
			gen ieps_`X'_`Y'n = ieps_`X'_`Y'*multiplier`Z'n_`Y'		


		}
	}
}



foreach Y in $sys2 $sys3 {

	gen iva_tot`Y'_new = 0
	gen ieps_tot`Y'_new= 0

	gen iva_tot`Y'_newn = 0
	gen ieps_tot`Y'_newn= 0

	foreach X of numlist 1(1)60 {

		replace iva_tot`Y'_new = iva_tot`Y'_new + iva_`X'_`Y'
		replace ieps_tot`Y'_new = ieps_tot`Y'_new + ieps_`X'_`Y' 

		replace iva_tot`Y'_newn = iva_tot`Y'_newn + iva_`X'_`Y'n
		replace ieps_tot`Y'_newn = ieps_tot`Y'_newn + ieps_`X'_`Y'n

	}
}

foreach Y in $sys2 $sys3 {

	gen hh_change_iva`Y' = iva_tot`Y'_new - iva_tot$sys1
	gen hh_change_ieps`Y' = ieps_tot`Y'_new - ieps_tot$sys1

	egen rev_iva`Y' = sum(hh_change_iva`Y'*factor)
	egen rev_ieps`Y' = sum(hh_change_ieps`Y'*factor)


	gen hh_change_iva`Y'n = iva_tot`Y'_newn - iva_tot$sys1
	gen hh_change_ieps`Y'n = ieps_tot`Y'_newn - ieps_tot$sys1

	egen rev_iva`Y'n = sum(hh_change_iva`Y'n*factor)
	egen rev_ieps`Y'n = sum(hh_change_ieps`Y'n*factor)
}

foreach Y in $sys2 $sys3 {

	gen hh_change_iva`Y'o = iva_tot`Y' - iva_tot$sys1
	gen hh_change_ieps`Y'o = ieps_tot`Y' - ieps_tot$sys1

	egen rev_iva`Y'o = sum(hh_change_iva`Y'o*factor)
	egen rev_ieps`Y'o = sum(hh_change_ieps`Y'o*factor)
}
qui {

gen num = 1
foreach Z in $sys2 $sys3 {

	foreach W in iva ieps {
	
		tabstat rev_`W'`Z'n, stats(mean) f(%20.0fc) by(num) save
		matrix a_`W'`Z'n = (r(Stat1))
		
		tabstat rev_`W'`Z'o, stats(mean) f(%20.0fc) by(num) save
		matrix a_`W'`Z'o = (r(Stat1))
	}
	
}

}


capture program drop log_revenue
program define log_revenue

local q = $sys2
local r = $sys3

set logtype text
log using "$out//$logfiledemand_revenue", replace

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~60s "Revenue raised from the tax reforms - after behavior " /*
				*/ _newline "" /*
				*/ _newline "   Tax        {c |}" %~25s "Reform System `q'" %~25s "Reform System `r'"   /*
				*/ _newline "{hline 14}{c +}{hline 50}"  /*
				*/ _newline as text " IVA          {c |}" as result "    $" %16.0fc a_iva`q'n[1,1] "         $" %16.0fc a_iva`r'n[1,1]  /*
				*/ _newline as text " IEPS         {c |}" as result "    $" %16.0fc a_ieps`q'n[1,1] "         $" %16.0fc a_ieps`r'n[1,1]  /*
				*/ _newline as text "{hline 14}{c +}{hline 50}"  

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~60s "Revenue raised from the tax reforms - before behavior " /*
				*/ _newline "" /*
				*/ _newline "   Tax        {c |}" %~25s "Reform System `q'" %~25s "Reform System `r'"   /*
				*/ _newline "{hline 14}{c +}{hline 50}"  /*
				*/ _newline as text " IVA          {c |}" as result "    $" %16.0fc a_iva`q'o[1,1] "         $" %16.0fc a_iva`r'o[1,1]  /*
				*/ _newline as text " IEPS         {c |}" as result "    $" %16.0fc a_ieps`q'o[1,1] "         $" %16.0fc a_ieps`r'o[1,1]  /*
				*/ _newline as text "{hline 14}{c +}{hline 50}"  


log close

end

log_revenue

