***********************************************************************************
* Latin-TAXBEN - The Flexible Tax Simulator for Middle Income Countries
* Build 2012-1
*
* Program name: set_taxbase.do
* Program purpose: This part of the program will calculate the taxable income by deducting any exemptions
*			 and deductions from the gross income calculated previously.
*
* Things to add
* Gross and Taxable Incomes to the Input Data
*
* Program created: 27 July 2010, by David Phillips
* Program updated: 09 November 2010, by David Phillips
* Program updated: 29 May 2012, by David Phillips (based on MEXTAX 2010 Build)
*
** Nombre del programa: set_taxbase.do
** Objectivo del programa: Este modelo del programa calcula ingresos tributables,
**                           restando las exenciones y deducciones tributarias del ingreso bruto
** Programa creado: 27 Julio 2010, por David Phillips
** Programa actualizado: 09 Noviembre 2010, por David Phillips
** Programa actualizado: 29 May 2012, por David Phillips
***********************************************************************************

local x = $indic_incidence

if `x' ==1 {
	use "$in\\$indata_ad", clear
}

if `x' ==2 {
	use "$in\\$indata_ad$sys2", clear
}

if `x' ==3 {
	use "$in\\$indata_ad$sys3", clear
}

noi display "SET DIRTAX BASE"
noi display "ESTABLECER BASE IMPOBIBLE PARA EL IMPUESTO DIRECTO"

****************************************************
**************** INCOME TAX BASE *******************
  ** BASE IMPONIBLE PARA EL IMPUESTO A LA RENTA
****************************************************

local z = NUMSOURCES

* CASH LIMITED EXEMPTIONS FOR EACH INCOME SOURCE
** EXENCIONES DE MONTO LIMITADO PARA CADA FUENTE DE INGRESO

foreach x of numlist 1(1)`z' {

	gen taxable_inc`x' = inc`x' - EXEMPT`x'
	replace taxable_inc`x' = 0 if taxable_inc`x' < 0

}

* PERCENTAGE EXEMPTIONS
** EXENCIONES PORCENTUALES

foreach x of numlist 1(1)`z' {

	replace taxable_inc`x' = 1*(1-PEXEMPT`x')*taxable_inc`x' if inc`x' < MPEXEMPT`x'
	replace taxable_inc`x' = (taxable_inc`x' - MPEXEMPT`x') + 1*(1-PEXEMPT`x')*MPEXEMPT`x' if inc`x' >= MPEXEMPT`x'

}

* CALCULATE TAXABLE INCOME BEFORE DEDUCTIONS
** CALCULAR INGRESO IMPOBIBLE ANTES DE DEDUCCIONES

	gen taxable_inc = taxable_inc1

foreach x of numlist 2(1)`z' {

	replace taxable_inc = taxable_inc + taxable_inc`x'

}



/* THIS SECTION ALLOWS CALCULATION OF DEDUCTIONS. FOR NOW IT IS COMMENTED OUT
* DEDUCTIONS

local zz = NUMDEDUCTIONS

foreach x of numlist 1(1)`zz' {

* CASH LIMITED DEDUCTIONS
** DEDUCCIONES DE MONTO LIMITADO

	gen deduct`x' = spend`x'
	replace deduct`x' = DEDUCT`x' if spend`x'>DEDUCT`x'
	replace deduct`x' = taxable_inc if deduct`X'>taxable_inc

* PROPORTION OF EXPENDITURE UPTO CASH LIMIT



* PROPORTION OF INCOME


}

gen deduct = deduct1

foreach x of numlist 2(1)`zz' {

	replace deduct = deduct + deduct`x'

}

	replace taxable_inc = taxable_inc - deduct
*/

****************************************************
************** SOCIAL SECURITY BASE ****************
   ** BASE IMPONIBLE PARA LA SEGURIDAD SOCIAL
****************************************************

* CASH EXEMPTIONS
** EXENCIONES DE MONTO FIJO

foreach x of numlist 1(1)`z' {

	gen socsec_inc`x' = inc`x' - SSEXEMPT`x'
	replace socsec_inc`x' = 0 if socsec_inc`x' < 0

}

* PERCENTAGE EXEMPTIONS
** EXENCIONES PORCENTUALES

foreach x of numlist 1(1)`z' {

	replace socsec_inc`x' = 1*(1-SSPEXEMPT`x')*socsec_inc`x' if inc`x' < SSMPEXEMPT`x'
	replace socsec_inc`x' = (socsec_inc`x' - SSMPEXEMPT`x') + 1*(1-SSPEXEMPT`x')*SSMPEXEMPT`x' if inc`x' >= SSMPEXEMPT`x'

}

	gen socsec_inc = socsec_inc1

foreach x of numlist 2(1)`z' {

	replace socsec_inc = socsec_inc + socsec_inc`x'

}

/*		**** COMMENTED OUT FOR NOW

* DEDUCTIONS
** DEDUCCIONES

foreach x of numlist 1(1)`zz' {

* CASH LIMITED DEDUCTIONS

	gen ssdeduct`x' = spend`x'
	replace ssdeduct`x' = SSDEDUCT`x' if spend`x'>SSDEDUCT`x'
	replace ssdeduct`x' = socsec_inc if ssdeduct`X'>socsec_inc

* PROPORTION OF EXPENDITURE UPTO CASH LIMIT


* PROPORTION OF INCOME


}

gen ssdeduct = ssdeduct1

foreach x of numlist 2(1)`zz' {

	replace ssdeduct = ssdeduct + ssdeduct`x'

}

	replace socsec_inc = socsec_inc - ssdeduct

*/

* GENERATE TOTAL GROSS INCOME

gen gross_$D = 0

foreach x of numlist 1(1)`z' {

        ***** NOTE: need to check what this should be for to allow calculation of PTR

    replace gross_$D = gross_$D + inc`x'  /*if EXEMPT`x'<1000000000*/

}

